import * as i0 from '@angular/core';
import { Injectable, Optional, Component, Inject, ElementRef, ViewChild, Input, NgModule, InjectionToken, inject, SkipSelf } from '@angular/core';
import { isDataSource } from '@angular/cdk/collections';
import { Subject, combineLatestWith, map, Observable, interval, BehaviorSubject, isObservable, of } from 'rxjs';
import { takeUntil } from 'rxjs/operators';
import * as i1$2 from '@ngrx/store';
import { createAction, createFeatureSelector, createSelector, props, createReducer, on, StoreModule } from '@ngrx/store';
import * as i1 from '@angular/cdk/layout';
import { Breakpoints, LayoutModule } from '@angular/cdk/layout';
import { isDate, isMoment } from 'moment';
import { DateTime } from 'luxon';
import * as i1$1 from '@angular/material/core';
import { DateAdapter, MAT_DATE_LOCALE } from '@angular/material/core';
import * as i3 from '@angular/material/button';
import { MatButtonModule } from '@angular/material/button';
import * as i4 from '@angular/material/icon';
import { MatIconModule } from '@angular/material/icon';
import * as i5 from '@angular/common';
import { CommonModule } from '@angular/common';
import * as i3$1 from '@angular/material/grid-list';
import { MatGridListModule } from '@angular/material/grid-list';
import * as i1$3 from '@angular/material/dialog';
import { MatDialogConfig, MAT_DIALOG_DATA, MatDialogModule } from '@angular/material/dialog';
import * as i5$1 from '@angular/material/list';
import { MatListModule } from '@angular/material/list';
import * as i6 from '@angular/material/divider';
import * as i5$2 from '@angular/material/card';
import { MatCardModule } from '@angular/material/card';
import { LuxonDateModule, LuxonDateAdapter, MAT_LUXON_DATE_ADAPTER_OPTIONS } from '@angular/material-luxon-adapter';
import { A11yModule } from '@angular/cdk/a11y';
import { BrowserAnimationsModule } from '@angular/platform-browser/animations';
import { DragDropModule } from '@angular/cdk/drag-drop';

const month = createAction('[view Component] month');
const week = createAction('[view Component] week');
const day = createAction('[view Component] day');

const upbytesCalendarFeatureKey = 'upbytes_calendar';
const selectCalendarState = createFeatureSelector(upbytesCalendarFeatureKey);
const selectCalendarViewState = createSelector(selectCalendarState, (state) => state._view);
const selectCalendarDateState = createSelector(selectCalendarState, (state) => state._date);

/**
 * @author vaibhav
 * implementaion of angular material Breakpoint.
 *
 */
const displayNameMap = new Map([
    [Breakpoints.XSmall, 'XSmall'],
    [Breakpoints.Small, 'Small'],
    [Breakpoints.Medium, 'Medium'],
    [Breakpoints.Large, 'Large'],
    [Breakpoints.XLarge, 'XLarge'],
]);
class CalendarViewPortService {
    constructor(breakpointObserver) {
        this.breakpointObserver = breakpointObserver;
        this.destroyed = new Subject();
        this.viewport = new Subject();
    }
    viewportResize() {
        this.breakpointObserver.observe([
            Breakpoints.XSmall,
            Breakpoints.Small,
            Breakpoints.Medium,
            Breakpoints.Large,
            Breakpoints.XLarge,
        ]).pipe(takeUntil(this.destroyed)).subscribe((result) => {
            for (const query of Object.keys(result.breakpoints)) {
                if (result.breakpoints[query]) {
                    this.currentScreenSize = displayNameMap.get(query) ?? 'Unknown';
                    this.viewport.next(this.currentScreenSize);
                }
            }
        });
    }
    ngOnDestroy() {
        this.viewport.next(this.currentScreenSize);
        this.destroyed.next();
        this.viewport.complete();
        this.destroyed.complete();
    }
}
CalendarViewPortService.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.1.1", ngImport: i0, type: CalendarViewPortService, deps: [{ token: i1.BreakpointObserver }], target: i0.ɵɵFactoryTarget.Injectable });
CalendarViewPortService.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "13.1.1", ngImport: i0, type: CalendarViewPortService, providedIn: 'root' });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.1.1", ngImport: i0, type: CalendarViewPortService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root'
                }]
        }], ctorParameters: function () { return [{ type: i1.BreakpointObserver }]; } });

class CalendarConfig {
}

/**
 * @author vaibhav
 * Calendar config service is used to config calendar data.
 *
 */
class CalendarServiceConfig {
    constructor(config) {
        if (config) {
            this._format = config.format;
            this._local = config.local;
            this._view = config.view;
        }
    }
    get format() {
        return this._format;
    }
    get local() {
        return this._local;
    }
    get view() {
        return this._view;
    }
}
CalendarServiceConfig.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.1.1", ngImport: i0, type: CalendarServiceConfig, deps: [{ token: CalendarConfig, optional: true }], target: i0.ɵɵFactoryTarget.Injectable });
CalendarServiceConfig.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "13.1.1", ngImport: i0, type: CalendarServiceConfig, providedIn: 'root' });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.1.1", ngImport: i0, type: CalendarServiceConfig, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root'
                }]
        }], ctorParameters: function () { return [{ type: CalendarConfig, decorators: [{
                    type: Optional
                }] }]; } });

/**
 * helps to return range of given length.
 * @param length
 * @param lamdaFunction
 * @returns T[]
 */
function dateRange(length, lamdaFunction) {
    const dateArr = Array(length);
    for (let i = 0; i < length; i++) {
        dateArr[i] = lamdaFunction(i);
    }
    return dateArr;
}
/**
 * @author vaibhav
 * Date service is perform various operation on dateTime. it is based on DateAdapter implementation
 * of angular material and DateTime object of Luxon library.
 * Manipulate date in number.
 *
 */
class DateService {
    constructor(_dateAdapter, calendarServiceConfig) {
        this._dateAdapter = _dateAdapter;
        this.calendarServiceConfig = calendarServiceConfig;
    }
    today() {
        return { current: this._dateAdapter.today() };
    }
    addCalendarYears(date, years) {
        return { current: this._dateAdapter.addCalendarYears(date.current, years) };
    }
    addCalendarMonths(date, months) {
        return { current: this._dateAdapter.addCalendarMonths(date.current, months) };
    }
    addCalendarDays(date, days) {
        return { current: this._dateAdapter.addCalendarDays(date.current, days) };
    }
    addCalendarWeeks(date, weeks) {
        return { current: date.current.plus({ weeks: weeks }) };
    }
    subtractCalendarYears(date, years) {
        return { current: date.current.minus({ years: years }) };
    }
    subtractCalendarMonths(date, months) {
        return { current: date.current.minus({ months: months }) };
    }
    subtractCalendarDays(date, days) {
        return { current: date.current.minus({ days: days }) };
    }
    subtractCalendarWeeks(date, weeks) {
        return { current: date.current.minus({ weeks: weeks }) };
    }
    getMonthNames(date, style) {
        return style === 'long' ? date.current.monthLong : date.current.monthShort;
    }
    getYearName(date) {
        return this._dateAdapter.getYearName(date.current);
    }
    getDayName(date, style) {
        return style === 'long' ? date.current.weekdayLong : date.current.weekdayShort;
    }
    getYear(date) {
        return this._dateAdapter.getYear(date.current);
    }
    getMonth(date) {
        return this._dateAdapter.getMonth(date.current);
    }
    getDate(date) {
        return this._dateAdapter.getDate(date.current);
    }
    getFirstDayOfMonth(date) {
        return {
            current: this._dateAdapter
                .createDate(this.getYear(date), this.getMonth(date), 1)
        };
    }
    getLastDayOfMonth(date) {
        return {
            current: this._dateAdapter
                .createDate(this.getYear(date), this.getMonth(date), date.current.daysInMonth)
        };
    }
    getFirstDayOfWeek(date) {
        return { current: date.current.startOf('week') };
    }
    getLastDayOfWeek(date) {
        return { current: date.current.endOf('week') };
    }
    getDaysInMonthRange(date) {
        return this.getLastDayOfWeek(this.getLastDayOfMonth(date))
            .current.diff(this.getFirstDayOfWeek(date).current, 'days').days;
    }
    getDayOfWeekNames(style) {
        return this._dateAdapter.getDayOfWeekNames(style);
    }
    getDayOfWeekNamesFromMonday(style) {
        const days = this.getDayOfWeekNames(style);
        return [...days.slice(1), days[0]];
    }
    getMonthDatesRange(date) {
        const dates = Array(35);
        let first = this.getFirstDayOfWeek(this.getFirstDayOfMonth(date));
        dates[0] = first;
        for (let i = 1; i < 35; i++) {
            first = this.addCalendarDays(first, 1);
            dates[i] = first;
        }
        return dates;
    }
    getWeekDatesRange(date) {
        const dates = Array(7);
        let first = this.getFirstDayOfWeek(date);
        dates[0] = first;
        for (let i = 1; i < 7; i++) {
            first = this.addCalendarDays(first, 1);
            dates[i] = first;
        }
        return dates;
    }
    getHoursFormat() {
        return dateRange(24, (i) => this.today().current
            .set({ hour: i, minute: 0 }).toFormat('hh:mm a'));
    }
    isToday(date) {
        return this.today().current.startOf('day').equals(date.current.startOf('day'));
    }
    isHoursNow(hours) {
        return this.today().current.set({ minute: 0 })
            .toFormat('hh:mm a') === hours;
    }
    getTimeZoneFormat(date) {
        return `GMT ${this._dateAdapter.format(date.current, 'Z')}`;
    }
    getDateTime(d) {
        return typeof d === 'number' ? DateTime.fromMillis(d) : this.getDateTimeFromFormat(d);
    }
    getDateTimeFromFormat(d) {
        return this.calendarServiceConfig.format ?
            DateTime.fromFormat(d, this.calendarServiceConfig.format) : DateTime.fromISO(d);
    }
    getDateTimeFromString(d) {
        return DateTime.fromISO(d);
    }
    isSameHour(hours, eventDate) {
        return this.getDateTime(eventDate)
            .set({ minute: 0 }).toFormat('hh:mm a') === hours;
    }
    isSameDate(date, eventDate) {
        return typeof date === 'object' ?
            this._dateAdapter.sameDate(date.current, this.getDateTime(eventDate)) :
            this._dateAdapter.sameDate(this.getDateTime(date), this.getDateTime(eventDate));
    }
    timeDiff(start, end) {
        return this.getDateTime(end)
            .diff(this.getDateTime(start), ['months', 'days', 'hours', 'minutes'])
            .toObject();
    }
    timeDiffinHours(start, end) {
        return this.timeDiff(start, end).hours;
    }
    timeDiffinMinutes(start, end) {
        const diff = this.timeDiff(start, end);
        return diff.hours * 60 + diff.minutes;
    }
    minute(start) {
        return this.getDateTime(start).minute;
    }
    getTimeFormat(d) {
        return this.getDateTime(d).toFormat('hh:mm a');
    }
    restoreFromStore(d) {
        return { current: this.getDateTime(d.current.toMillis()) };
    }
    isBetween(date, start, end) {
        return start < date.current.toMillis()
            && date.current.toMillis() < end;
    }
    setDate(date, month, year, _currentDate) {
        return { current: _currentDate.current.set({ day: date, month: month, year: year }) };
    }
}
DateService.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.1.1", ngImport: i0, type: DateService, deps: [{ token: i1$1.DateAdapter }, { token: CalendarServiceConfig, optional: true }], target: i0.ɵɵFactoryTarget.Injectable });
DateService.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "13.1.1", ngImport: i0, type: DateService, providedIn: 'root' });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.1.1", ngImport: i0, type: DateService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root'
                }]
        }], ctorParameters: function () { return [{ type: i1$1.DateAdapter }, { type: CalendarServiceConfig, decorators: [{
                    type: Optional
                }] }]; } });

/**
 * @author vaibhav
 * calendar event adpater service is used to convert input data into CalendarEventInput
 */
class CalendarEventInputAdapter {
    constructor(_dateService) {
        this._dateService = _dateService;
    }
    /**
     * this function is adapt any input into CalenarEventInput
     * @param item accept any type of input
     * @returns CalenarEventInput
     */
    adapt(item) {
        return this.createCalendarEventInput(item);
    }
    /**
     * convert data into CalendarEventInput
     * @param data
     * @returns CalendarEventInput
     */
    createCalendarEventInput(data) {
        return {
            start: this.convertToMillis(data.start),
            end: this.convertToMillis(data.end),
            title: data.title,
            color: data.color,
            description: data.description
        };
    }
    /**
     * convert date into milliseconds
     * @param d input date
     * @returns date into milliseconds
     */
    convertToMillis(d) {
        if (isDate(d)) {
            return d.getMilliseconds();
        }
        else if (isMoment(d)) {
            return d.milliseconds();
        }
        else if (typeof d == 'string') {
            return this._dateService.getDateTime(d).toMillis();
        }
        else if (typeof d == 'number') {
            return this._dateService.getDateTime(d).toMillis();
        }
        else if (DateTime.isDateTime(d)) {
            return d.toMillis();
        }
        return DateTime.now().toMillis();
    }
    /**
     * sort CalendarEventInput array
     * @param e array ofCalndarEventInput
     * @returns sorted array
     */
    sort(e) {
        return e.sort((a, b) => a.start - b.start);
    }
}
CalendarEventInputAdapter.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.1.1", ngImport: i0, type: CalendarEventInputAdapter, deps: [{ token: DateService }], target: i0.ɵɵFactoryTarget.Injectable });
CalendarEventInputAdapter.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "13.1.1", ngImport: i0, type: CalendarEventInputAdapter, providedIn: 'root' });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.1.1", ngImport: i0, type: CalendarEventInputAdapter, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root',
                }]
        }], ctorParameters: function () { return [{ type: DateService }]; } });

const increment = createAction('[Date Component] Increment', props());
const decrement = createAction('[Date Component] Decrement', props());
const reset = createAction('[Date Component] Reset', props());
const goto = createAction('[Date Component] Goto', props());

/**
 * @author vaibhav
 *
 * calendar navigator component display left side of calednar header.
 * Prev: this button will move current view of calendar to previous view according to view selected
 * Next: this button will move current view of calendar to next view according to view selected
 * Today: this button will move current view of calendar to
 * current date view according to view selected
 */
class CalendarNavigatorComponent {
    constructor(dstore, vstore, calendarViewPortService) {
        this.dstore = dstore;
        this.vstore = vstore;
        this.calendarViewPortService = calendarViewPortService;
        this.date$ = dstore.select(selectCalendarDateState);
        this.date$.subscribe((d) => this._currentDate = d);
        this._view$ = vstore.select(selectCalendarViewState);
        this._view$.subscribe((v) => this._view = v);
        this.calendarViewPortService.viewport.subscribe(s => this.viewport = s);
    }
    /**
     * This function will dispatch a increment action to store.
     */
    increment() {
        this.dstore.dispatch(increment(this._view));
    }
    /**
     * This function will dispatch a decrement action to store.
     */
    decrement() {
        this.dstore.dispatch(decrement(this._view));
    }
    /**
     * This function will dispatch a reset action to store.
     */
    reset() {
        this.dstore.dispatch(reset(this._view));
    }
    get size() {
        return this.viewport !== 'Small' && this.viewport !== 'XSmall';
    }
}
CalendarNavigatorComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.1.1", ngImport: i0, type: CalendarNavigatorComponent, deps: [{ token: i1$2.Store }, { token: i1$2.Store }, { token: CalendarViewPortService }], target: i0.ɵɵFactoryTarget.Component });
CalendarNavigatorComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "13.1.1", type: CalendarNavigatorComponent, selector: "upbytes-angular-material-calendar-navigator", ngImport: i0, template: "<ng-template [ngIf]=\"size\">\n    <button mat-raised-button id=\"calendar-navigator-previous\" color=\"primary\" aria-label=\"Previous\" (click)=\"decrement()\">\n        <mat-icon class=\"calendar-navigator-button  material-icons-round\">chevron_left</mat-icon>\n        Prev\n    </button>\n    <button mat-raised-button id=\"calendar-navigator-next\" color=\"primary\" aria-label=\"Next\" (click)=\"increment()\">\n        Next\n        <mat-icon class=\"calendar-navigator-button material-icons-round\">\n            chevron_right\n        </mat-icon>\n    </button>\n    <button mat-raised-button id=\"calendar-navigator-today\" class=\"calendar-navigator-today\" color=\"primary\" aria-label=\"current date\" (click)=\"reset()\">\n        <mat-icon class=\"calendar-navigator-button  material-icons-round \">today</mat-icon>\n        Today\n    </button>\n</ng-template>\n\n<ng-template [ngIf]=\"!size\">\n    <button mat-icon-button color=\"primary\" aria-label=\"Previous\" (click)=\"decrement()\">\n        <mat-icon class=\"calendar-navigator-button  material-icons-round\">chevron_left</mat-icon>\n    </button>\n    <button mat-icon-button color=\"primary\" aria-label=\"Next\" (click)=\"increment()\">\n        <mat-icon class=\"calendar-navigator-button  material-icons-round\">chevron_right</mat-icon>\n    </button>\n    <button mat-icon-button color=\"primary\" aria-label=\"current date\" (click)=\"reset()\">\n        <mat-icon class=\"calendar-navigator-button material-icons-round\">today</mat-icon>\n    </button>\n</ng-template>", styles: [".calendar-navigator-button{font-size:1.5em}.calendar-navigator-today{margin-left:1em}\n"], components: [{ type: i3.MatButton, selector: "button[mat-button], button[mat-raised-button], button[mat-icon-button],             button[mat-fab], button[mat-mini-fab], button[mat-stroked-button],             button[mat-flat-button]", inputs: ["disabled", "disableRipple", "color"], exportAs: ["matButton"] }, { type: i4.MatIcon, selector: "mat-icon", inputs: ["color", "inline", "svgIcon", "fontSet", "fontIcon"], exportAs: ["matIcon"] }], directives: [{ type: i5.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.1.1", ngImport: i0, type: CalendarNavigatorComponent, decorators: [{
            type: Component,
            args: [{ selector: 'upbytes-angular-material-calendar-navigator', template: "<ng-template [ngIf]=\"size\">\n    <button mat-raised-button id=\"calendar-navigator-previous\" color=\"primary\" aria-label=\"Previous\" (click)=\"decrement()\">\n        <mat-icon class=\"calendar-navigator-button  material-icons-round\">chevron_left</mat-icon>\n        Prev\n    </button>\n    <button mat-raised-button id=\"calendar-navigator-next\" color=\"primary\" aria-label=\"Next\" (click)=\"increment()\">\n        Next\n        <mat-icon class=\"calendar-navigator-button material-icons-round\">\n            chevron_right\n        </mat-icon>\n    </button>\n    <button mat-raised-button id=\"calendar-navigator-today\" class=\"calendar-navigator-today\" color=\"primary\" aria-label=\"current date\" (click)=\"reset()\">\n        <mat-icon class=\"calendar-navigator-button  material-icons-round \">today</mat-icon>\n        Today\n    </button>\n</ng-template>\n\n<ng-template [ngIf]=\"!size\">\n    <button mat-icon-button color=\"primary\" aria-label=\"Previous\" (click)=\"decrement()\">\n        <mat-icon class=\"calendar-navigator-button  material-icons-round\">chevron_left</mat-icon>\n    </button>\n    <button mat-icon-button color=\"primary\" aria-label=\"Next\" (click)=\"increment()\">\n        <mat-icon class=\"calendar-navigator-button  material-icons-round\">chevron_right</mat-icon>\n    </button>\n    <button mat-icon-button color=\"primary\" aria-label=\"current date\" (click)=\"reset()\">\n        <mat-icon class=\"calendar-navigator-button material-icons-round\">today</mat-icon>\n    </button>\n</ng-template>", styles: [".calendar-navigator-button{font-size:1.5em}.calendar-navigator-today{margin-left:1em}\n"] }]
        }], ctorParameters: function () { return [{ type: i1$2.Store }, { type: i1$2.Store }, { type: CalendarViewPortService }]; } });

/**
 * @author vaibhav
 * The calendar header label component display month name and year.
 */
class CalendarHeaderLabelComponent {
    constructor(store, calendarViewPortService, _dateService) {
        this.store = store;
        this.calendarViewPortService = calendarViewPortService;
        this._dateService = _dateService;
        this.date$ = store.select((selector) => selector.upbytes_calendar._date);
        this.date$.subscribe((d) => this._currentDate = d);
        this.calendarViewPortService.viewport.subscribe(s => this.viewport = s);
    }
    /**
     * @returns month long name
     */
    get month() {
        return this.size ?
            this._dateService.getMonthNames(this._currentDate, 'long')
            : this._dateService.getMonthNames(this._currentDate, 'short');
    }
    /**
     * @returns year long name
     */
    get year() {
        return this._dateService.getYearName(this._currentDate);
    }
    /**
     * @returns month and year label
     */
    get label() {
        return `${this.month} ${this.year}`;
    }
    /**
     * invoke when size of view port change
     * @returns boolean false in case of screen small
     */
    get size() {
        return this.viewport !== 'Small' && this.viewport !== 'XSmall';
    }
}
CalendarHeaderLabelComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.1.1", ngImport: i0, type: CalendarHeaderLabelComponent, deps: [{ token: i1$2.Store }, { token: CalendarViewPortService }, { token: DateService }], target: i0.ɵɵFactoryTarget.Component });
CalendarHeaderLabelComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "13.1.1", type: CalendarHeaderLabelComponent, selector: "upbytes-angular-material-calendar-label", ngImport: i0, template: "<mat-lable [ngClass]=\"size ? 'header-label-font-x-large' : 'header-label-font-small'\">\n    {{label}}\n</mat-lable>\n", directives: [{ type: i5.NgClass, selector: "[ngClass]", inputs: ["class", "ngClass"] }] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.1.1", ngImport: i0, type: CalendarHeaderLabelComponent, decorators: [{
            type: Component,
            args: [{ selector: 'upbytes-angular-material-calendar-label', template: "<mat-lable [ngClass]=\"size ? 'header-label-font-x-large' : 'header-label-font-small'\">\n    {{label}}\n</mat-lable>\n" }]
        }], ctorParameters: function () { return [{ type: i1$2.Store }, { type: CalendarViewPortService }, { type: DateService }]; } });

/**
 * @author vaibhav
 * Calendar toggel component will be display right top corner of the calendar header. Toggle
 * button will switch view in between day/week/month.
 */
class CalendarHeaderToggelComponent {
    constructor(store, calendarViewPortService) {
        this.store = store;
        this.calendarViewPortService = calendarViewPortService;
        this._view$ = store.select(selectCalendarViewState);
        this._view$.subscribe((v) => this._view = v);
        this.calendarViewPortService.viewport.subscribe(s => this.viewport = s);
    }
    /**
     * use to dispatch month view in store
     */
    month() {
        this.store.dispatch(month());
    }
    /**
     * use to dispatch week view in store
     */
    week() {
        this.store.dispatch(week());
    }
    /**
     * use to dispatch day view in store
     */
    day() {
        this.store.dispatch(day());
    }
    get size() {
        return this.viewport !== 'Small' && this.viewport !== 'XSmall';
    }
}
CalendarHeaderToggelComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.1.1", ngImport: i0, type: CalendarHeaderToggelComponent, deps: [{ token: i1$2.Store }, { token: CalendarViewPortService }], target: i0.ɵɵFactoryTarget.Component });
CalendarHeaderToggelComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "13.1.1", type: CalendarHeaderToggelComponent, selector: "upbytes-angular-material-calendar-toggel", ngImport: i0, template: "<ng-template [ngIf]=\"size\">\n        <button mat-raised-button id=\"calendar-toggel-day\" [ngClass]=\"_view!.view === 'day' ? 'calendar-header-toggle-selected' : 'mat-primary'\"\n                aria-label=\"Select Day View\" (click)=\"day()\">\n                <mat-icon class=\"calendar-toggel-button material-icons-round\">calendar_view_day</mat-icon>\n                Day\n        </button>\n        <button mat-raised-button id=\"calendar-toggel-week\" aria-label=\"Select Week View\"\n                [ngClass]=\"_view!.view === 'week' ? 'calendar-header-toggle-selected' : 'mat-primary'\" (click)=\"week()\">\n                <mat-icon class=\"calendar-toggel-button material-icons-round\">calendar_view_week</mat-icon>\n                Week\n        </button>\n        <button mat-raised-button id=\"calendar-toggel-month\" aria-label=\"Select Month View\"\n                [ngClass]=\"_view!.view === 'month' ? 'calendar-header-toggle-selected' : 'mat-primary'\"\n                (click)=\"month()\">\n                <mat-icon class=\"calendar-toggel-button material-icons-round\">calendar_view_month</mat-icon>\n                Month\n        </button>\n</ng-template>\n<ng-template [ngIf]=\"!size\">\n        <button mat-icon-button [ngClass]=\"_view!.view === 'day' ? 'calendar-header-toggle-selected' : 'mat-primary'\"\n                aria-label=\"Select Day View\" (click)=\"day()\">\n                <mat-icon class=\"calendar-toggel-button material-icons-round\">calendar_view_day</mat-icon>\n                \n        </button>\n        <button mat-icon-button aria-label=\"Select Week View\"\n                [ngClass]=\"_view!.view === 'week' ? 'calendar-header-toggle-selected' : 'mat-primary'\" (click)=\"week()\">\n                <mat-icon class=\"calendar-toggel-button material-icons-round\">calendar_view_week</mat-icon>\n                \n        </button>\n        <button mat-icon-button aria-label=\"Select Month View\"\n                [ngClass]=\"_view!.view === 'month' ? 'calendar-header-toggle-selected' : 'mat-primary'\"\n                (click)=\"month()\">\n                <mat-icon class=\"calendar-toggel-button material-icons-round\">calendar_view_month</mat-icon>\n                \n        </button>\n</ng-template>", styles: [".calendar-toggel-button{font-size:1.5em}\n"], components: [{ type: i3.MatButton, selector: "button[mat-button], button[mat-raised-button], button[mat-icon-button],             button[mat-fab], button[mat-mini-fab], button[mat-stroked-button],             button[mat-flat-button]", inputs: ["disabled", "disableRipple", "color"], exportAs: ["matButton"] }, { type: i4.MatIcon, selector: "mat-icon", inputs: ["color", "inline", "svgIcon", "fontSet", "fontIcon"], exportAs: ["matIcon"] }], directives: [{ type: i5.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { type: i5.NgClass, selector: "[ngClass]", inputs: ["class", "ngClass"] }] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.1.1", ngImport: i0, type: CalendarHeaderToggelComponent, decorators: [{
            type: Component,
            args: [{ selector: 'upbytes-angular-material-calendar-toggel', template: "<ng-template [ngIf]=\"size\">\n        <button mat-raised-button id=\"calendar-toggel-day\" [ngClass]=\"_view!.view === 'day' ? 'calendar-header-toggle-selected' : 'mat-primary'\"\n                aria-label=\"Select Day View\" (click)=\"day()\">\n                <mat-icon class=\"calendar-toggel-button material-icons-round\">calendar_view_day</mat-icon>\n                Day\n        </button>\n        <button mat-raised-button id=\"calendar-toggel-week\" aria-label=\"Select Week View\"\n                [ngClass]=\"_view!.view === 'week' ? 'calendar-header-toggle-selected' : 'mat-primary'\" (click)=\"week()\">\n                <mat-icon class=\"calendar-toggel-button material-icons-round\">calendar_view_week</mat-icon>\n                Week\n        </button>\n        <button mat-raised-button id=\"calendar-toggel-month\" aria-label=\"Select Month View\"\n                [ngClass]=\"_view!.view === 'month' ? 'calendar-header-toggle-selected' : 'mat-primary'\"\n                (click)=\"month()\">\n                <mat-icon class=\"calendar-toggel-button material-icons-round\">calendar_view_month</mat-icon>\n                Month\n        </button>\n</ng-template>\n<ng-template [ngIf]=\"!size\">\n        <button mat-icon-button [ngClass]=\"_view!.view === 'day' ? 'calendar-header-toggle-selected' : 'mat-primary'\"\n                aria-label=\"Select Day View\" (click)=\"day()\">\n                <mat-icon class=\"calendar-toggel-button material-icons-round\">calendar_view_day</mat-icon>\n                \n        </button>\n        <button mat-icon-button aria-label=\"Select Week View\"\n                [ngClass]=\"_view!.view === 'week' ? 'calendar-header-toggle-selected' : 'mat-primary'\" (click)=\"week()\">\n                <mat-icon class=\"calendar-toggel-button material-icons-round\">calendar_view_week</mat-icon>\n                \n        </button>\n        <button mat-icon-button aria-label=\"Select Month View\"\n                [ngClass]=\"_view!.view === 'month' ? 'calendar-header-toggle-selected' : 'mat-primary'\"\n                (click)=\"month()\">\n                <mat-icon class=\"calendar-toggel-button material-icons-round\">calendar_view_month</mat-icon>\n                \n        </button>\n</ng-template>", styles: [".calendar-toggel-button{font-size:1.5em}\n"] }]
        }], ctorParameters: function () { return [{ type: i1$2.Store }, { type: CalendarViewPortService }]; } });

class CalendarHeaderComponent {
}
CalendarHeaderComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.1.1", ngImport: i0, type: CalendarHeaderComponent, deps: [], target: i0.ɵɵFactoryTarget.Component });
CalendarHeaderComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "13.1.1", type: CalendarHeaderComponent, selector: "upbytes-angular-material-calendar-header", ngImport: i0, template: "<upbytes-angular-material-calendar-navigator class=\"header-navigator\">    \n</upbytes-angular-material-calendar-navigator>\n<upbytes-angular-material-calendar-label class=\"header-label header-label-font header-label-font-color\">\n</upbytes-angular-material-calendar-label>\n<upbytes-angular-material-calendar-toggel class=\"header-toggel\">\n</upbytes-angular-material-calendar-toggel>\n", styles: [".header-label{flex:1;display:flex;justify-content:center;align-items:center}.header-navigator{flex:1;display:flex;justify-content:flex-start;align-items:flex-start}.header-toggel{flex:1;display:flex;justify-content:flex-end;align-items:flex-end}\n"], components: [{ type: CalendarNavigatorComponent, selector: "upbytes-angular-material-calendar-navigator" }, { type: CalendarHeaderLabelComponent, selector: "upbytes-angular-material-calendar-label" }, { type: CalendarHeaderToggelComponent, selector: "upbytes-angular-material-calendar-toggel" }] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.1.1", ngImport: i0, type: CalendarHeaderComponent, decorators: [{
            type: Component,
            args: [{ selector: 'upbytes-angular-material-calendar-header', template: "<upbytes-angular-material-calendar-navigator class=\"header-navigator\">    \n</upbytes-angular-material-calendar-navigator>\n<upbytes-angular-material-calendar-label class=\"header-label header-label-font header-label-font-color\">\n</upbytes-angular-material-calendar-label>\n<upbytes-angular-material-calendar-toggel class=\"header-toggel\">\n</upbytes-angular-material-calendar-toggel>\n", styles: [".header-label{flex:1;display:flex;justify-content:center;align-items:center}.header-navigator{flex:1;display:flex;justify-content:flex-start;align-items:flex-start}.header-toggel{flex:1;display:flex;justify-content:flex-end;align-items:flex-end}\n"] }]
        }] });

class MonthViewService {
    constructor(_dateService) {
        this._dateService = _dateService;
    }
    getMonthViewDates(date) {
        const monthDates = this._dateService.getMonthDatesRange(date);
        return monthDates.map((d) => this.createMonthViewDate(d));
    }
    getCalendarDateEventMap(date, events) {
        const dates = this._dateService.getMonthDatesRange(date);
        const data = new Map();
        dates.map((d) => {
            const gridDate = this.createMonthViewDate(d);
            data.set(gridDate, []);
            events.map((event) => {
                if (this._dateService.isSameDate(d, event.start)
                    || this._dateService.isBetween(d, event.start, event.end)) {
                    data.get(gridDate)?.push(event);
                }
            });
        });
        return data;
    }
    // need to be fixed to get first day as a monday always
    getDayOfWeeksNames(style) {
        return this._dateService.getDayOfWeekNamesFromMonday(style);
    }
    createMonthViewDate(date) {
        return {
            date: this._dateService.getDate(date),
            day: this._dateService.getDayName(date, 'short'),
            month: this._dateService.getMonth(date) + 1,
            year: this._dateService.getYear(date),
            isEnable: this._dateService.getMonth(date) === this._dateService.getMonth(date),
            isToday: this._dateService.isToday(date)
        };
    }
    setDate(selected, _currentDate) {
        return this._dateService.setDate(selected.date, selected.month, selected.year, _currentDate);
    }
}
MonthViewService.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.1.1", ngImport: i0, type: MonthViewService, deps: [{ token: DateService }], target: i0.ɵɵFactoryTarget.Injectable });
MonthViewService.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "13.1.1", ngImport: i0, type: MonthViewService, providedIn: 'root' });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.1.1", ngImport: i0, type: MonthViewService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root'
                }]
        }], ctorParameters: function () { return [{ type: DateService }]; } });

/**
 * @author vaibhav
 * calendar month view grid header component will display short weekday name
 */
class CalendarMonthViewGridHeaderComponent {
    constructor(_monthViewService) {
        this._monthViewService = _monthViewService;
        this.dayOfWeekNames = this._monthViewService.getDayOfWeeksNames('short');
    }
}
CalendarMonthViewGridHeaderComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.1.1", ngImport: i0, type: CalendarMonthViewGridHeaderComponent, deps: [{ token: MonthViewService }], target: i0.ɵɵFactoryTarget.Component });
CalendarMonthViewGridHeaderComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "13.1.1", type: CalendarMonthViewGridHeaderComponent, selector: "upbytes-angular-material-calendar-month-view-grid-header", ngImport: i0, template: "<mat-grid-list cols=\"7\" \n               rowHeight=\"1.5em\" \n               gutterSize=\"0\"\n>\n    <mat-grid-tile tabindex=\"0\" class=\"calendar-month-view-grid-header\" aria-label=\"name\"\n        *ngFor=\"let name of dayOfWeekNames\">\n             {{name}}\n    </mat-grid-tile>\n</mat-grid-list>", styles: [""], components: [{ type: i3$1.MatGridList, selector: "mat-grid-list", inputs: ["cols", "gutterSize", "rowHeight"], exportAs: ["matGridList"] }, { type: i3$1.MatGridTile, selector: "mat-grid-tile", inputs: ["rowspan", "colspan"], exportAs: ["matGridTile"] }], directives: [{ type: i5.NgForOf, selector: "[ngFor][ngForOf]", inputs: ["ngForOf", "ngForTrackBy", "ngForTemplate"] }] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.1.1", ngImport: i0, type: CalendarMonthViewGridHeaderComponent, decorators: [{
            type: Component,
            args: [{ selector: 'upbytes-angular-material-calendar-month-view-grid-header', template: "<mat-grid-list cols=\"7\" \n               rowHeight=\"1.5em\" \n               gutterSize=\"0\"\n>\n    <mat-grid-tile tabindex=\"0\" class=\"calendar-month-view-grid-header\" aria-label=\"name\"\n        *ngFor=\"let name of dayOfWeekNames\">\n             {{name}}\n    </mat-grid-tile>\n</mat-grid-list>", styles: [""] }]
        }], ctorParameters: function () { return [{ type: MonthViewService }]; } });

/**
 * @author vaibhav
 * This service is used to identify conflicting events and change left and width fraction
 * according to events conflicts.
 */
class EventNode {
    constructor() {
        this.max = 0;
    }
}
class CalendarEventConflictService {
    constructor() { }
    /**
     * takes CalendarEventFull as a  input and return EventNode object
     * @param i CalendarEventFull
     * @returns EventNode
     */
    eventNode(i) {
        const temp = new EventNode();
        temp.i = i;
        temp.max = i.end;
        return temp;
    }
    /**
     * insert event node into tree
     * @param root EventNode
     * @param i CalendarEventFull
     * @returns EventNode
     */
    insertEventNode(root, i) {
        if (root == null) {
            return this.eventNode(i);
        }
        const l = root.i?.start;
        if (i.start < l) {
            root.left = this.insertEventNode(root.left, i);
        }
        else {
            root.right = this.insertEventNode(root.right, i);
        }
        if (root.max < i.end) {
            root.max = i.end;
        }
        return root;
    }
    /**
     * check if two events are conflicting
     * @param i1 CalendarEventFull
     * @param i2 CalendarEventFull
     * @returns boolean
     */
    isConflict(i1, i2) {
        if (i1.start < i2.end && i2.start < i1.end) {
            return true;
        }
        return false;
    }
    /**
     * search conflicting events in tree. add new events into tree.
     * @param root EventNode
     * @param i CalendarEventFull
     * @param conflictingEvents
     * @returns CalendarEventFull
     */
    conflictSearch(root, i, conflictingEvents) {
        if (root == null) {
            return {};
        }
        if (this.isConflict(root.i, i)) {
            conflictingEvents.push(root.i);
        }
        if (root.left != null &&
            root.left.max >= i.start) {
            return this.conflictSearch(root.left, i, conflictingEvents);
        }
        return this.conflictSearch(root.right, i, conflictingEvents);
    }
    /**
     * call from other service with input data.
     * @param events CalendarEventFull[]
     * @param days number
     */
    conflicting(events, days) {
        let root;
        root = this.insertEventNode(root, events[0]);
        for (let i = 1; i < events.length; i++) {
            const conflictingEvents = [];
            this.conflictSearch(root, events[i], conflictingEvents);
            events[i].conflics = conflictingEvents.length;
            conflictingEvents.push(events[i]);
            this.conflictedEventFr(conflictingEvents, days);
            root = this.insertEventNode(root, events[i]);
        }
    }
    /**
     * update conflicting events left and width franction
     * @param conflicts CalendarEventFull[]
     * @param days number
     * @returns CalendarEventFull[]
     */
    conflictedEventFr(conflicts, days) {
        conflicts.forEach((c, index) => {
            c.widthFr = 1 / conflicts.length;
            c.leftFr = c.left + (days * index) / conflicts.length;
        });
        return conflicts;
    }
}
CalendarEventConflictService.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.1.1", ngImport: i0, type: CalendarEventConflictService, deps: [], target: i0.ɵɵFactoryTarget.Injectable });
CalendarEventConflictService.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "13.1.1", ngImport: i0, type: CalendarEventConflictService, providedIn: 'root' });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.1.1", ngImport: i0, type: CalendarEventConflictService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root'
                }]
        }], ctorParameters: function () { return []; } });

/**
 * @author vaibhav
 * calendar event servies is use to input style on event snippets.
 */
class CalendarEventService {
    constructor(_dateService, _calendarEventConflictService) {
        this._dateService = _dateService;
        this._calendarEventConflictService = _calendarEventConflictService;
    }
    setEventStyle(event, _element, left, top, width, height) {
        this.styleWidth(event, _element, width);
        this.styleLeft(event, _element, left);
        this.styleTop(event, _element, top);
        this.styleHeight(event, _element, height);
        this.styleBackground(event, _element);
    }
    calc(exp) {
        return `calc(${exp})`;
    }
    styleLeft(event, _element, left) {
        if (event.conflics > 0 && event.leftFr > 1) {
            _element.nativeElement.style['left'] =
                this.calc(`(${left} - 0px + 0px) * ${event.leftFr}`);
        }
        else {
            _element.nativeElement.style['left']
                = this.calc(`(${left} - 0px + 0px) * ${event.left}`);
        }
    }
    styleTop(event, _element, top) {
        _element.nativeElement.style['top']
            = !event.isAllDay ?
                this.calc(`(${top} + 0px) * ${event.top}
                + ${this.calculateEventStartOffset(event)}`) : '5px';
    }
    styleWidth(event, _element, width) {
        _element.nativeElement.style['width']
            = this.calc(`(${width}% - 0px) * ${event.widthFr} + 0px`);
    }
    styleHeight(event, _element, height) {
        _element.nativeElement.style['height'] =
            !event.isAllDay ? this.calc(`${this.calculateEventHeight(event)}`) : height;
    }
    styleBackground(event, _element) {
        _element.nativeElement.style['background-color'] =
            `${event.color}`;
    }
    calculateEventStartOffset(event) {
        return `${this._dateService.minute(event.start) / 12}em`;
    }
    calculateEventHeight(event) {
        return `${this._dateService.timeDiffinMinutes(event.start, event.end) / 12}em`;
    }
    eventsubtitle(event) {
        return `${this._dateService.getTimeFormat(event.start)}
        - ${this._dateService.getTimeFormat(event.end)}`;
    }
    createCalendarEventFull(final, top, left) {
        return {
            start: final.start,
            end: final.end,
            title: final.title,
            color: final.color,
            format: final.format,
            description: final.description,
            left: left,
            top: top,
            height: this.calculateEventHeightFraction(final),
            widthFr: 1,
            conflics: 0,
            leftFr: 1
        };
    }
    calculateEventHeightFraction(e) {
        return this._dateService.timeDiffinMinutes(e.start, e.end) / 12;
    }
    filterEventsBySameLeft(events) {
        const eventMap = new Map();
        events.forEach((e) => {
            if (eventMap.has(e.left)) {
                eventMap.get(e.left)?.push(e);
            }
            else {
                eventMap.set(e.left, Array.of(e));
            }
        });
        return eventMap;
    }
    filteredConflictedEvents(events, days) {
        const eventMap = this.filterEventsBySameLeft(events);
        eventMap.forEach((v) => {
            this._calendarEventConflictService.conflicting(v, days);
        });
        return events;
    }
    isAllDayEvent(event) {
        event.isAllDay = !this._dateService.isSameDate(event.end, event.start);
        return event;
    }
    allDayEventWidth(event) {
        if (event.isAllDay) {
            const diff = this._dateService.getDateTime(event.end).day
                - this._dateService.getDateTime(event.start).day + 1;
            event.widthFr = diff;
        }
        return event;
    }
    eventFullTime(event) {
        const start = this._dateService.getDateTime(event.start);
        return `${start.weekdayShort} ${start.day}
        /${start.month}/${start.year} 
        ${this._dateService.getTimeFormat(event.start)}
         - ${this._dateService.getTimeFormat(event.end)}`;
    }
}
CalendarEventService.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.1.1", ngImport: i0, type: CalendarEventService, deps: [{ token: DateService }, { token: CalendarEventConflictService }], target: i0.ɵɵFactoryTarget.Injectable });
CalendarEventService.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "13.1.1", ngImport: i0, type: CalendarEventService, providedIn: 'root' });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.1.1", ngImport: i0, type: CalendarEventService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root'
                }]
        }], ctorParameters: function () { return [{ type: DateService }, { type: CalendarEventConflictService }]; } });

/**
 * @author vaibhav
 * calendar event dialog component is used to display event complete data.
 */
class CalendarEventDialog {
    constructor(_element, dialogRef, event, position, calendarEventService) {
        this._element = _element;
        this.dialogRef = dialogRef;
        this.event = event;
        this.position = position;
        this.calendarEventService = calendarEventService;
        this.time = this.calendarEventService.eventFullTime(this.event.edata);
        this.positionRelativeToElement = position.positionRelativeToElement;
    }
    ngOnInit() {
        const matDialogConfig = this.setDialogPosition();
        this.dialogRef.updatePosition(matDialogConfig.position);
        this.setDialogBackground();
    }
    /**
     * use to set dialoge position according to event clicked.
     * @returns MatDialogConfig
     */
    setDialogPosition() {
        const matDialogConfig = new MatDialogConfig();
        const rect = this.positionRelativeToElement.nativeElement.getBoundingClientRect();
        matDialogConfig.position = {
            top: `${10}em`
        };
        if (this.event.edata.left > 4) {
            matDialogConfig.position.right = `${rect.left}px`;
        }
        else {
            matDialogConfig.position.left = `${rect.left + rect.width}px`;
        }
        matDialogConfig.position = {
            top: `${10}em`
        };
        return matDialogConfig;
    }
    /**
     * display dialoge backgrond accroding to event color
     */
    setDialogBackground() {
        this._element.nativeElement.parentElement.style.background = this.event.edata.color;
    }
    close() {
        this.dialogRef.close();
    }
}
CalendarEventDialog.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.1.1", ngImport: i0, type: CalendarEventDialog, deps: [{ token: i0.ElementRef }, { token: i1$3.MatDialogRef }, { token: MAT_DIALOG_DATA }, { token: MAT_DIALOG_DATA }, { token: CalendarEventService }], target: i0.ɵɵFactoryTarget.Component });
CalendarEventDialog.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "13.1.1", type: CalendarEventDialog, selector: "upbytes-angular-material-calendar-event-dialog", ngImport: i0, template: "<div mat-dialog-title class=\"calendar-event-dialog-title\">\n    <button mat-icon-button (click)=\"close()\">\n        <mat-icon class=\"calendar-toggel-button\">close</mat-icon>\n    </button>\n</div>\n<mat-dialog-content>\n    <mat-list class=\"calendar-event-dialog\">\n        <mat-list-item>\n            <mat-icon mat-list-icon class=\"material-icons-round\">title</mat-icon>\n            <div mat-line class=\"calendar-event-line\">{{event!.edata.title}}</div>\n        </mat-list-item>\n        <mat-divider></mat-divider>\n        <mat-list-item>\n            <mat-icon mat-list-icon class=\"material-icons-round\">schedule</mat-icon>\n            <div mat-line class=\"calendar-event-line\">{{time!}}</div>\n        </mat-list-item>\n        <mat-divider></mat-divider>\n        <mat-list-item *ngIf=\"event!.edata.description!\">\n            <mat-icon mat-list-icon class=\"material-icons-round\">description</mat-icon>\n            <div mat-line class=\"calendar-event-line\">{{event!.edata.description}}</div>\n        </mat-list-item>\n\n    </mat-list>\n</mat-dialog-content>", styles: ["calendar-event-dialog1 .mat-dialog-container .mat-dialog-container{padding:0}calendar-event-dialog-white-backdrop{background:#fff!important}\n"], components: [{ type: i3.MatButton, selector: "button[mat-button], button[mat-raised-button], button[mat-icon-button],             button[mat-fab], button[mat-mini-fab], button[mat-stroked-button],             button[mat-flat-button]", inputs: ["disabled", "disableRipple", "color"], exportAs: ["matButton"] }, { type: i4.MatIcon, selector: "mat-icon", inputs: ["color", "inline", "svgIcon", "fontSet", "fontIcon"], exportAs: ["matIcon"] }, { type: i5$1.MatList, selector: "mat-list, mat-action-list", inputs: ["disableRipple", "disabled"], exportAs: ["matList"] }, { type: i5$1.MatListItem, selector: "mat-list-item, a[mat-list-item], button[mat-list-item]", inputs: ["disableRipple", "disabled"], exportAs: ["matListItem"] }, { type: i6.MatDivider, selector: "mat-divider", inputs: ["vertical", "inset"] }], directives: [{ type: i1$3.MatDialogTitle, selector: "[mat-dialog-title], [matDialogTitle]", inputs: ["id"], exportAs: ["matDialogTitle"] }, { type: i1$3.MatDialogContent, selector: "[mat-dialog-content], mat-dialog-content, [matDialogContent]" }, { type: i5$1.MatListIconCssMatStyler, selector: "[mat-list-icon], [matListIcon]" }, { type: i1$1.MatLine, selector: "[mat-line], [matLine]" }, { type: i5.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.1.1", ngImport: i0, type: CalendarEventDialog, decorators: [{
            type: Component,
            args: [{ selector: 'upbytes-angular-material-calendar-event-dialog', template: "<div mat-dialog-title class=\"calendar-event-dialog-title\">\n    <button mat-icon-button (click)=\"close()\">\n        <mat-icon class=\"calendar-toggel-button\">close</mat-icon>\n    </button>\n</div>\n<mat-dialog-content>\n    <mat-list class=\"calendar-event-dialog\">\n        <mat-list-item>\n            <mat-icon mat-list-icon class=\"material-icons-round\">title</mat-icon>\n            <div mat-line class=\"calendar-event-line\">{{event!.edata.title}}</div>\n        </mat-list-item>\n        <mat-divider></mat-divider>\n        <mat-list-item>\n            <mat-icon mat-list-icon class=\"material-icons-round\">schedule</mat-icon>\n            <div mat-line class=\"calendar-event-line\">{{time!}}</div>\n        </mat-list-item>\n        <mat-divider></mat-divider>\n        <mat-list-item *ngIf=\"event!.edata.description!\">\n            <mat-icon mat-list-icon class=\"material-icons-round\">description</mat-icon>\n            <div mat-line class=\"calendar-event-line\">{{event!.edata.description}}</div>\n        </mat-list-item>\n\n    </mat-list>\n</mat-dialog-content>", styles: ["calendar-event-dialog1 .mat-dialog-container .mat-dialog-container{padding:0}calendar-event-dialog-white-backdrop{background:#fff!important}\n"] }]
        }], ctorParameters: function () { return [{ type: i0.ElementRef }, { type: i1$3.MatDialogRef }, { type: undefined, decorators: [{
                    type: Inject,
                    args: [MAT_DIALOG_DATA]
                }] }, { type: undefined, decorators: [{
                    type: Inject,
                    args: [MAT_DIALOG_DATA]
                }] }, { type: CalendarEventService }]; } });

/**
 * @author vaibhav
 * use to open and close calendar event dialog.
 */
class CalendarEventDialogeService {
    constructor(dialog) {
        this.dialog = dialog;
    }
    openDialog({ edata, positionRelativeToElement, hasBackdrop = false, height = '25em', width = '30em', backdropClass, panelClass }) {
        const dialogRef = this.dialog.open(CalendarEventDialog, {
            hasBackdrop: hasBackdrop,
            height: height,
            width: width,
            panelClass: panelClass,
            backdropClass: backdropClass,
            data: {
                positionRelativeToElement: positionRelativeToElement,
                edata: edata
            }
        });
        return dialogRef;
    }
}
CalendarEventDialogeService.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.1.1", ngImport: i0, type: CalendarEventDialogeService, deps: [{ token: i1$3.MatDialog }], target: i0.ɵɵFactoryTarget.Injectable });
CalendarEventDialogeService.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "13.1.1", ngImport: i0, type: CalendarEventDialogeService, providedIn: 'root' });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.1.1", ngImport: i0, type: CalendarEventDialogeService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root'
                }]
        }], ctorParameters: function () { return [{ type: i1$3.MatDialog }]; } });

/**
 * @author vaibhav
 * Calendar event view component is used to display events on month view grid
 */
class CalendarEventViewComponent {
    constructor(monthViewService, calendarEventService, calendarEventDialogService) {
        this.monthViewService = monthViewService;
        this.calendarEventService = calendarEventService;
        this.calendarEventDialogService = calendarEventDialogService;
    }
    /**
     * use to display title on mat-card subtitle
     * @param e CalendarEventFull
     * @returns combine start datetime and end datetime
     */
    getTitle(e) {
        return this.time = this.calendarEventService.eventsubtitle(e);
    }
    /**
     * open mat-dialog to display event content
     * @param e CalendarEventFull
     */
    openEventDialog(e) {
        this.calendarEventDialogService.openDialog({
            edata: e,
            positionRelativeToElement: this.eventViewRef,
            hasBackdrop: true,
            backdropClass: 'calendar-event-dialog-white-backdrop',
            panelClass: 'calendar-event-dialog'
        });
    }
}
CalendarEventViewComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.1.1", ngImport: i0, type: CalendarEventViewComponent, deps: [{ token: MonthViewService }, { token: CalendarEventService }, { token: CalendarEventDialogeService }], target: i0.ɵɵFactoryTarget.Component });
CalendarEventViewComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "13.1.1", type: CalendarEventViewComponent, selector: "upbytes-angular-material-calendar-event-view", inputs: { events: "events" }, viewQueries: [{ propertyName: "eventViewRef", first: true, predicate: ["eventView"], descendants: true, read: ElementRef }], ngImport: i0, template: "<ng-template ngFor let-e [ngForOf]=\"events\" let-i=\"index\">\n  <mat-card #eventView *ngIf=\"i<2\" class=\"calendar-event-view-content\"\n         [ngStyle]=\"{'background-color' : e.color}\" (click)=\"openEventDialog(e)\">\n         <mat-card-subtitle class=\"calendar-full-view-subtitle\" >\n             {{getTitle(e)!}}\n         </mat-card-subtitle>\n    </mat-card>\n</ng-template>", styles: [""], components: [{ type: i5$2.MatCard, selector: "mat-card", exportAs: ["matCard"] }], directives: [{ type: i5.NgForOf, selector: "[ngFor][ngForOf]", inputs: ["ngForOf", "ngForTrackBy", "ngForTemplate"] }, { type: i5.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { type: i5.NgStyle, selector: "[ngStyle]", inputs: ["ngStyle"] }, { type: i5$2.MatCardSubtitle, selector: "mat-card-subtitle, [mat-card-subtitle], [matCardSubtitle]" }] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.1.1", ngImport: i0, type: CalendarEventViewComponent, decorators: [{
            type: Component,
            args: [{ selector: 'upbytes-angular-material-calendar-event-view', template: "<ng-template ngFor let-e [ngForOf]=\"events\" let-i=\"index\">\n  <mat-card #eventView *ngIf=\"i<2\" class=\"calendar-event-view-content\"\n         [ngStyle]=\"{'background-color' : e.color}\" (click)=\"openEventDialog(e)\">\n         <mat-card-subtitle class=\"calendar-full-view-subtitle\" >\n             {{getTitle(e)!}}\n         </mat-card-subtitle>\n    </mat-card>\n</ng-template>", styles: [""] }]
        }], ctorParameters: function () { return [{ type: MonthViewService }, { type: CalendarEventService }, { type: CalendarEventDialogeService }]; }, propDecorators: { eventViewRef: [{
                type: ViewChild,
                args: ['eventView', { read: ElementRef }]
            }], events: [{
                type: Input
            }] } });

/**
 * @author vaibhav
 *
 * CalendarMonthViewGridComponent: this component will display grid view of month dates
 * Events: events will be merge with calendar dates and display by
 * using calendar view dates template.
 */
class CalendarMonthViewGridComponent {
    constructor(store, _monthViewService) {
        this.store = store;
        this._monthViewService = _monthViewService;
        this.date$ = store.select(selectCalendarDateState);
    }
    /**
     * This function will combine date stream with event stream to intialize grid view.
     */
    ngOnInit() {
        this.date$?.pipe(combineLatestWith(this.events$), map(([date, events]) => {
            this._currentDate = date;
            return this._monthViewService.getCalendarDateEventMap(date, events);
        })).subscribe(data => this.monthViewDates = data);
    }
    /**
     * This function will return true if array have more than 2 events.
     * used to display event count
     * @param events calendar event input array as a parameter
     * @returns return boolean value is array has more than 2 events.
     */
    isCountVisible(events) {
        return events.length > 2;
    }
    /**
     * This function is used with user click on date value.
     * it will switch month view to day view.
     * @param e will take current calendar state as a input.
     */
    switchView(e) {
        this.goto(this._monthViewService.setDate(e, this._currentDate));
        this.store.dispatch(day());
    }
    /**
     * This fucntion is use to dispatch date to store.
     * @param _currentDate take current date as a input paramater
     */
    goto(_currentDate) {
        this.store.dispatch(goto(_currentDate));
    }
}
CalendarMonthViewGridComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.1.1", ngImport: i0, type: CalendarMonthViewGridComponent, deps: [{ token: i1$2.Store }, { token: MonthViewService }], target: i0.ɵɵFactoryTarget.Component });
CalendarMonthViewGridComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "13.1.1", type: CalendarMonthViewGridComponent, selector: "upbytes-angular-material-calendar-month-view-grid", inputs: { events$: "events$" }, ngImport: i0, template: "<mat-grid-list cols=\"7\" rowHeight=\"6em\" gutterSize=\"1.5\">\n    <ng-template ngFor let-tile [ngForOf]=\"monthViewDates | keyvalue\" let-i=\"index\">\n        <mat-grid-tile class=\"calendar-month-view-grid\"\n            [ngClass]=\"tile.key.isToday ? 'calendar-month-view-grid-date-today-border' : ''\">\n            <div *ngIf=\"tile.key.isToday\" class=\"calendar-month-view-grid-date-today\"></div>\n            <div tabindex=\"0\" [ngClass]=\"tile.key.isToday ? 'calendar-month-view-grid-date-today-text' : ''\"\n                class=\"calendar-month-view-grid-date\" \n                (click)=\"switchView(tile.key)\" (keydown)=\"switchView(tile.key)\">{{tile.key.date}}</div>\n            <upbytes-angular-material-calendar-event-view *ngIf=\"tile.value.length > 0\" tabindex=\"0\" [events]=\"tile.value\">\n            </upbytes-angular-material-calendar-event-view>\n            <div tabindex=\"0\" *ngIf=\"isCountVisible(tile.value)\" class=\"calendar-month-view-grid-footer\">\n                +{{tile.value.length}}\n            </div>\n        </mat-grid-tile>\n    </ng-template>\n</mat-grid-list>", styles: [""], components: [{ type: i3$1.MatGridList, selector: "mat-grid-list", inputs: ["cols", "gutterSize", "rowHeight"], exportAs: ["matGridList"] }, { type: i3$1.MatGridTile, selector: "mat-grid-tile", inputs: ["rowspan", "colspan"], exportAs: ["matGridTile"] }, { type: CalendarEventViewComponent, selector: "upbytes-angular-material-calendar-event-view", inputs: ["events"] }], directives: [{ type: i5.NgForOf, selector: "[ngFor][ngForOf]", inputs: ["ngForOf", "ngForTrackBy", "ngForTemplate"] }, { type: i5.NgClass, selector: "[ngClass]", inputs: ["class", "ngClass"] }, { type: i5.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }], pipes: { "keyvalue": i5.KeyValuePipe } });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.1.1", ngImport: i0, type: CalendarMonthViewGridComponent, decorators: [{
            type: Component,
            args: [{ selector: 'upbytes-angular-material-calendar-month-view-grid', template: "<mat-grid-list cols=\"7\" rowHeight=\"6em\" gutterSize=\"1.5\">\n    <ng-template ngFor let-tile [ngForOf]=\"monthViewDates | keyvalue\" let-i=\"index\">\n        <mat-grid-tile class=\"calendar-month-view-grid\"\n            [ngClass]=\"tile.key.isToday ? 'calendar-month-view-grid-date-today-border' : ''\">\n            <div *ngIf=\"tile.key.isToday\" class=\"calendar-month-view-grid-date-today\"></div>\n            <div tabindex=\"0\" [ngClass]=\"tile.key.isToday ? 'calendar-month-view-grid-date-today-text' : ''\"\n                class=\"calendar-month-view-grid-date\" \n                (click)=\"switchView(tile.key)\" (keydown)=\"switchView(tile.key)\">{{tile.key.date}}</div>\n            <upbytes-angular-material-calendar-event-view *ngIf=\"tile.value.length > 0\" tabindex=\"0\" [events]=\"tile.value\">\n            </upbytes-angular-material-calendar-event-view>\n            <div tabindex=\"0\" *ngIf=\"isCountVisible(tile.value)\" class=\"calendar-month-view-grid-footer\">\n                +{{tile.value.length}}\n            </div>\n        </mat-grid-tile>\n    </ng-template>\n</mat-grid-list>", styles: [""] }]
        }], ctorParameters: function () { return [{ type: i1$2.Store }, { type: MonthViewService }]; }, propDecorators: { events$: [{
                type: Input
            }] } });

class CalendarMonthViewComponent {
}
CalendarMonthViewComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.1.1", ngImport: i0, type: CalendarMonthViewComponent, deps: [], target: i0.ɵɵFactoryTarget.Component });
CalendarMonthViewComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "13.1.1", type: CalendarMonthViewComponent, selector: "upbytes-angular-material-calendar-month-view", inputs: { events$: "events$" }, ngImport: i0, template: "<upbytes-angular-material-calendar-month-view-grid-header>\n</upbytes-angular-material-calendar-month-view-grid-header>\n<upbytes-angular-material-calendar-month-view-grid [events$]=\"events$\">\n</upbytes-angular-material-calendar-month-view-grid>", styles: [""], components: [{ type: CalendarMonthViewGridHeaderComponent, selector: "upbytes-angular-material-calendar-month-view-grid-header" }, { type: CalendarMonthViewGridComponent, selector: "upbytes-angular-material-calendar-month-view-grid", inputs: ["events$"] }] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.1.1", ngImport: i0, type: CalendarMonthViewComponent, decorators: [{
            type: Component,
            args: [{ selector: 'upbytes-angular-material-calendar-month-view', template: "<upbytes-angular-material-calendar-month-view-grid-header>\n</upbytes-angular-material-calendar-month-view-grid-header>\n<upbytes-angular-material-calendar-month-view-grid [events$]=\"events$\">\n</upbytes-angular-material-calendar-month-view-grid>", styles: [""] }]
        }], propDecorators: { events$: [{
                type: Input
            }] } });

function bifilter(f, xs) {
    /* eslint-disable @typescript-eslint/naming-convention */
    return xs.reduce(([T, F], e) => !f(e) ? [T, [...F, e]] : [[...T, e], F], [[], []]);
}
/**
 * @author vaibhav
 * used by day/week view to create grid data.
 */
class CalendarHoursService {
    constructor(_dateService, _calendarEventService) {
        this._dateService = _dateService;
        this._calendarEventService = _calendarEventService;
    }
    getCalendarHours() {
        const hours = this._dateService.getHoursFormat().map((d) => ({
            hours: d,
            isHourNow: this._dateService.isHoursNow(d),
            date: 0,
            day: '',
            isAllDay: false
        }));
        hours.unshift(this.addAllDayEventRow());
        return hours;
    }
    getCalendarWeekRange(date) {
        const dates = this._dateService.getWeekDatesRange(date);
        return this.pushFirstRowForGrid(dates);
    }
    getCalndarWeekHoursGridData(date) {
        const dates = this.getCalendarWeekRange(date);
        return this.getCalendarHours().map((c) => dates.map((h) => {
            const ch = this.createCalendarHours(h, c);
            return ch;
        }));
    }
    getCalndarDayHoursGridData(date) {
        const dates = this.pushFirstRowForGrid(Array.of(date));
        return this.getCalendarHours().map((c) => dates.map((h) => {
            const ch = this.createCalendarHours(h, c);
            return ch;
        }));
    }
    pushFirstRowForGrid(dates) {
        const hours = dates.map((d) => ({
            day: this._dateService.getDayName(d, 'short'),
            date: this._dateService.getDate(d),
            isToday: this._dateService.isToday(d),
            month: this._dateService.getMonth(d),
            year: this._dateService.getYear(d),
            cDate: d
        }));
        hours.unshift(this.createFirstRowDate(dates[0]));
        return hours;
    }
    createFirstRowDate(date) {
        return {
            timeZone: this._dateService.getTimeZoneFormat(date),
            isFirst: true
        };
    }
    createCalendarHours(h, c) {
        return {
            hours: c.hours,
            day: h.day,
            date: h.date,
            isHourNow: c.isHourNow,
            isToday: h.isToday,
            timeZone: h.timeZone,
            isFirst: h.isFirst,
            cDate: h.cDate
        };
    }
    filterEventsByDateAndStartTime(events, calendarHours) {
        const filteredEvents = [];
        calendarHours.forEach((hours, i) => {
            hours.forEach((h, j) => {
                events.forEach((e) => {
                    if (h.cDate && this._dateService.isSameDate(h.cDate, e.start) &&
                        this._dateService.isSameHour(h.hours, e.start)) {
                        filteredEvents.push(this._calendarEventService.createCalendarEventFull(e, i, j));
                    }
                });
            });
        });
        return filteredEvents;
    }
    filterMultipleDayEvents(events) {
        return bifilter(((e) => !this._dateService.isSameDate(e.end, e.start)), events);
    }
    findLeftForMultiDaysEventWeek(events, calendarDate) {
        const filteredEvents = [];
        this.getCalendarWeekRange(calendarDate).forEach((hours, i) => {
            events.forEach((e) => {
                if (hours.cDate && this._dateService.isSameDate(hours.cDate, e.start)) {
                    filteredEvents.push(this._calendarEventService.createCalendarEventFull(e, 0, i));
                }
            });
        });
        return filteredEvents;
    }
    findLeftForMultiDaysEventDay(events, calendarDate) {
        const filteredEvents = [];
        this.pushFirstRowForGrid(Array.of(calendarDate)).forEach((hours, i) => {
            events.forEach((e) => {
                if (hours.cDate && this._dateService.isSameDate(hours.cDate, e.start)
                    || hours.cDate && this._dateService.isBetween(hours.cDate, e.start, e.end)) {
                    filteredEvents.push(this._calendarEventService.createCalendarEventFull(e, 0, i));
                }
            });
        });
        return filteredEvents;
    }
    addAllDayEventRow() {
        return {
            hours: '0',
            isHourNow: false,
            date: 0,
            day: '',
            isAllDay: true
        };
    }
}
CalendarHoursService.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.1.1", ngImport: i0, type: CalendarHoursService, deps: [{ token: DateService }, { token: CalendarEventService }], target: i0.ɵɵFactoryTarget.Injectable });
CalendarHoursService.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "13.1.1", ngImport: i0, type: CalendarHoursService, providedIn: 'root' });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.1.1", ngImport: i0, type: CalendarHoursService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root'
                }]
        }], ctorParameters: function () { return [{ type: DateService }, { type: CalendarEventService }]; } });

/**
 * @author vaibhav
 * calendar week view header comoponent should be displayed short weekdays name and GTM +timezone
 */
class CalendarWeekViewHeaderComponent {
    constructor(store, _calendarWeekService) {
        this.store = store;
        this._calendarWeekService = _calendarWeekService;
        this.date$ = store.select(selectCalendarDateState);
        this.date$.subscribe((d) => {
            this._currentDate = d;
            this.calendarHours = this._calendarWeekService.getCalendarWeekRange(this._currentDate);
        });
    }
}
CalendarWeekViewHeaderComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.1.1", ngImport: i0, type: CalendarWeekViewHeaderComponent, deps: [{ token: i1$2.Store }, { token: CalendarHoursService }], target: i0.ɵɵFactoryTarget.Component });
CalendarWeekViewHeaderComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "13.1.1", type: CalendarWeekViewHeaderComponent, selector: "upbytes-angular-material-calendar-week-view-header", ngImport: i0, template: "<div class=\"calendar-week-view-header-border\">\n    <mat-grid-list cols=\"8\" rowHeight=\"5em\" gutterSize=\"0\">\n\n        <mat-grid-tile class=\"calendar-week-view-header\"\n            [ngClass]=\"tile.isToday ? 'calendar-week-view-header-today' : ''\"\n            *ngFor=\"let tile of calendarHours; let i=index; \">\n            <div *ngIf=\"tile.isFirst\" class=\"calendar-week-view-header-first\">\n                {{tile.timeZone}}\n            </div>\n            <div class=\"calendar-week-view-header-content\">\n            <div class=\"calendar-week-view-header-font\">\n                {{tile.date}}\n            </div>\n            <div class=\"calendar-week-view-header-day\">\n                {{tile.day}}\n            </div>\n            </div>\n        </mat-grid-tile>\n    </mat-grid-list>\n\n</div>", styles: [""], components: [{ type: i3$1.MatGridList, selector: "mat-grid-list", inputs: ["cols", "gutterSize", "rowHeight"], exportAs: ["matGridList"] }, { type: i3$1.MatGridTile, selector: "mat-grid-tile", inputs: ["rowspan", "colspan"], exportAs: ["matGridTile"] }], directives: [{ type: i5.NgForOf, selector: "[ngFor][ngForOf]", inputs: ["ngForOf", "ngForTrackBy", "ngForTemplate"] }, { type: i5.NgClass, selector: "[ngClass]", inputs: ["class", "ngClass"] }, { type: i5.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.1.1", ngImport: i0, type: CalendarWeekViewHeaderComponent, decorators: [{
            type: Component,
            args: [{ selector: 'upbytes-angular-material-calendar-week-view-header', template: "<div class=\"calendar-week-view-header-border\">\n    <mat-grid-list cols=\"8\" rowHeight=\"5em\" gutterSize=\"0\">\n\n        <mat-grid-tile class=\"calendar-week-view-header\"\n            [ngClass]=\"tile.isToday ? 'calendar-week-view-header-today' : ''\"\n            *ngFor=\"let tile of calendarHours; let i=index; \">\n            <div *ngIf=\"tile.isFirst\" class=\"calendar-week-view-header-first\">\n                {{tile.timeZone}}\n            </div>\n            <div class=\"calendar-week-view-header-content\">\n            <div class=\"calendar-week-view-header-font\">\n                {{tile.date}}\n            </div>\n            <div class=\"calendar-week-view-header-day\">\n                {{tile.day}}\n            </div>\n            </div>\n        </mat-grid-tile>\n    </mat-grid-list>\n\n</div>", styles: [""] }]
        }], ctorParameters: function () { return [{ type: i1$2.Store }, { type: CalendarHoursService }]; } });

const LEFT = '12.5%';
const TOP$1 = '5em';
const HEIGHT = '5em';
/**
 * @author vaibhav
 * calendar event full view component is use to display events on day/week view
 */
class CalendarEventFullViewComponent {
    constructor(store, _element, calendarEventService, calendarEventDialogService, dialog) {
        this.store = store;
        this._element = _element;
        this.calendarEventService = calendarEventService;
        this.calendarEventDialogService = calendarEventDialogService;
        this.dialog = dialog;
        this._view$ = store.select(selectCalendarViewState);
        this._view$.subscribe((v) => this._view = v);
    }
    ngOnInit() {
        const width = this._view?.view === 'week' ? 12.5 : 87.5;
        this.event = this.calendarEventService.isAllDayEvent(this.event);
        this.event = this._view?.view === 'week' ?
            this.calendarEventService.allDayEventWidth(this.event) : this.event;
        this.calendarEventService.setEventStyle(this.event, this._element, LEFT, TOP$1, width, HEIGHT);
        this.time = this.calendarEventService.eventsubtitle(this.event);
    }
    /**
     * open mat-dialoge to display event content
     */
    openEventDialog() {
        this.calendarEventDialogService.openDialog({
            edata: this.event,
            positionRelativeToElement: this.eventfullviewRef,
            hasBackdrop: true,
            backdropClass: 'calendar-event-dialog-white-backdrop',
            panelClass: 'calendar-event-dialog'
        });
    }
}
CalendarEventFullViewComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.1.1", ngImport: i0, type: CalendarEventFullViewComponent, deps: [{ token: i1$2.Store }, { token: i0.ElementRef }, { token: CalendarEventService }, { token: CalendarEventDialogeService }, { token: i1$3.MatDialog }], target: i0.ɵɵFactoryTarget.Component });
CalendarEventFullViewComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "13.1.1", type: CalendarEventFullViewComponent, selector: "upbytes-angular-material-calendar-event-full-view", inputs: { event: "event" }, viewQueries: [{ propertyName: "eventfullviewRef", first: true, predicate: ["eventfullview"], descendants: true, read: ElementRef }], ngImport: i0, template: "<mat-card #eventfullview class=\"calendar-full-view-content\"\n         [ngStyle]=\"{'background-color' : event!.color}\"\n         (click)=\"openEventDialog()\">\n    <mat-card-subtitle class=\"calendar-full-view-subtitle\" >{{time!}}</mat-card-subtitle>\n    <mat-card-content class=\"calendar-card-content\" >{{event!.title}}</mat-card-content>\n</mat-card>", styles: [""], components: [{ type: i5$2.MatCard, selector: "mat-card", exportAs: ["matCard"] }], directives: [{ type: i5.NgStyle, selector: "[ngStyle]", inputs: ["ngStyle"] }, { type: i5$2.MatCardSubtitle, selector: "mat-card-subtitle, [mat-card-subtitle], [matCardSubtitle]" }, { type: i5$2.MatCardContent, selector: "mat-card-content, [mat-card-content], [matCardContent]" }] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.1.1", ngImport: i0, type: CalendarEventFullViewComponent, decorators: [{
            type: Component,
            args: [{ selector: 'upbytes-angular-material-calendar-event-full-view', template: "<mat-card #eventfullview class=\"calendar-full-view-content\"\n         [ngStyle]=\"{'background-color' : event!.color}\"\n         (click)=\"openEventDialog()\">\n    <mat-card-subtitle class=\"calendar-full-view-subtitle\" >{{time!}}</mat-card-subtitle>\n    <mat-card-content class=\"calendar-card-content\" >{{event!.title}}</mat-card-content>\n</mat-card>", styles: [""] }]
        }], ctorParameters: function () { return [{ type: i1$2.Store }, { type: i0.ElementRef }, { type: CalendarEventService }, { type: CalendarEventDialogeService }, { type: i1$3.MatDialog }]; }, propDecorators: { eventfullviewRef: [{
                type: ViewChild,
                args: ['eventfullview', { read: ElementRef }]
            }], event: [{
                type: Input
            }] } });

/**
 * @author vaibhav
 * will move hour indicator in every minute.
 *
 */
class CalendarHourIndicatorService {
    constructor(_dateService) {
        this._dateService = _dateService;
        this.updateTop();
    }
    updateTop() {
        this.currentTime = this._dateService.today().current;
        this.hour = this.currentTime.hour;
        this.minute = this.currentTime.minute;
    }
    /* esling-disable */
    styleTop(_element, top) {
        _element.nativeElement.style['top']
            = this.calc(`(${top} + 0px) * ${this.hour + 1}
            + ${this.calculateEventStartOffset()}`);
    }
    calculateEventStartOffset() {
        return `${this.minute / 12}em`;
    }
    calc(exp) {
        return `calc(${exp})`;
    }
}
CalendarHourIndicatorService.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.1.1", ngImport: i0, type: CalendarHourIndicatorService, deps: [{ token: DateService }], target: i0.ɵɵFactoryTarget.Injectable });
CalendarHourIndicatorService.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "13.1.1", ngImport: i0, type: CalendarHourIndicatorService, providedIn: 'root' });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.1.1", ngImport: i0, type: CalendarHourIndicatorService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root'
                }]
        }], ctorParameters: function () { return [{ type: DateService }]; } });

const ID = '-hour-indicator';
const TOP = '5em';
class CalendarHourIndicatorComponent {
    constructor(store, hourIndicatorService) {
        this.store = store;
        this.hourIndicatorService = hourIndicatorService;
        this._destroyed$ = new Subject();
        this._interval$ = new Observable();
        this._interval$ = interval(1000);
        this._view$ = store.select(selectCalendarViewState);
        this._view$.subscribe((v) => {
            this._view = v;
            this.id = `${this._view.view}${ID}`;
        });
        this._interval$.pipe(takeUntil(this._destroyed$)).subscribe(() => {
            this.hourIndicatorService.updateTop();
            this.setTop();
        });
    }
    ngAfterViewInit() {
        this.setTop();
    }
    setTop() {
        this.hourIndicatorService.styleTop(this.hourindicatorRef, TOP);
    }
    ngOnDestroy() {
        this._destroyed$.next();
        this._destroyed$.complete();
    }
}
CalendarHourIndicatorComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.1.1", ngImport: i0, type: CalendarHourIndicatorComponent, deps: [{ token: i1$2.Store }, { token: CalendarHourIndicatorService }], target: i0.ɵɵFactoryTarget.Component });
CalendarHourIndicatorComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "13.1.1", type: CalendarHourIndicatorComponent, selector: "upbytes-angular-material-calendar-hour-indicator", viewQueries: [{ propertyName: "hourindicatorRef", first: true, predicate: ["hourindicator"], descendants: true, read: ElementRef }], ngImport: i0, template: "<mat-divider #hourindicator class=\"calendar-hour-indicator\" id=\"{{id}}\"></mat-divider>", styles: [""], components: [{ type: i6.MatDivider, selector: "mat-divider", inputs: ["vertical", "inset"] }] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.1.1", ngImport: i0, type: CalendarHourIndicatorComponent, decorators: [{
            type: Component,
            args: [{ selector: 'upbytes-angular-material-calendar-hour-indicator', template: "<mat-divider #hourindicator class=\"calendar-hour-indicator\" id=\"{{id}}\"></mat-divider>", styles: [""] }]
        }], ctorParameters: function () { return [{ type: i1$2.Store }, { type: CalendarHourIndicatorService }]; }, propDecorators: { hourindicatorRef: [{
                type: ViewChild,
                args: ['hourindicator', { read: ElementRef }]
            }] } });

/**
 * @author vaibhav
 * calendar week view gird component will display grid view of week date and time.
 *
 */
class CalendarWeekViewGridComponent {
    constructor(store, _calendarWeekService, _calendarEventService) {
        this.store = store;
        this._calendarWeekService = _calendarWeekService;
        this._calendarEventService = _calendarEventService;
        this.date$ = store.select(selectCalendarDateState);
    }
    /**
     * Component lifecycle ngOnInit will initialize view
     */
    ngOnInit() {
        this.date$?.pipe(combineLatestWith(this.events$)).subscribe(([d, events]) => {
            this._currentDate = d;
            this.calendarHours = this._calendarWeekService
                .getCalndarWeekHoursGridData(this._currentDate);
            const filteredEventsArr = this._calendarWeekService.filterMultipleDayEvents(events);
            this.multipleDayEvents = this._calendarWeekService
                .findLeftForMultiDaysEventWeek(filteredEventsArr[0], this._currentDate);
            this.calendarEventsFull = this._calendarWeekService
                .filterEventsByDateAndStartTime(filteredEventsArr[1], this.calendarHours);
            this.calendarEventsFull = this._calendarEventService
                .filteredConflictedEvents(this.calendarEventsFull, 1);
        });
    }
    /**
     * component lifecycle hook will scroll view to current hour.
     */
    ngAfterViewInit() {
        document.getElementById(`week-hour-indicator`)?.scrollIntoView({
            behavior: 'smooth',
            block: 'center',
            inline: 'center'
        });
    }
    trackByHour(index, el) {
        return el.hours;
    }
}
CalendarWeekViewGridComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.1.1", ngImport: i0, type: CalendarWeekViewGridComponent, deps: [{ token: i1$2.Store }, { token: CalendarHoursService }, { token: CalendarEventService }], target: i0.ɵɵFactoryTarget.Component });
CalendarWeekViewGridComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "13.1.1", type: CalendarWeekViewGridComponent, selector: "upbytes-angular-material-calendar-week-view-grid", inputs: { events$: "events$" }, ngImport: i0, template: "<mat-grid-list cols=\"8\" \n               rowHeight=\"5em\" \n               gutterSize=\"0\">\n\n    <ng-template ngFor let-days \n                [ngForOf]=\"calendarHours\" \n                let-i=\"index\">\n\n                <mat-grid-tile class=\"calendar-week-view-grid\" \n                               id=\"week-{{trackByHour(i, tile)}}\"\n                               \n                               [ngClass]=\"[\n                               tile.isToday ? 'calendar-week-view-grid-today' : '',\n                               tile.isHourNow ? 'calendar-week-view-grid-hours' : '']\"\n                               *ngFor=\"let tile of days; let i=index; trackBy: trackByHour\">\n                               <div *ngIf=\"tile.isFirst && tile.hours! !== '0'\"\n                                     [ngClass]=\"tile.isFirst ? 'calendar-day-view-grid-first' : ''\" >\n                                   {{tile.hours}}\n                                   {{tile.day}}\n                               </div>\n                               <div *ngIf=\"tile.isFirst && tile.hours! === '0'\" \n                                    [ngClass]=\"tile.isFirst ? 'calendar-day-view-grid-first' : ''\" >\n                                     all-day\n                               </div>\n                               <div *ngIf=!tile.isFirst \n                               [ngClass]=\"!tile.isFirst ? 'calendar-week-view-grid-hour' : ''\" >\n                                   \n                               </div>\n\n                </mat-grid-tile>\n      </ng-template>\n      <ng-template ngFor let-event\n                   [ngForOf]=\"calendarEventsFull\" \n                   let-i=\"index\">\n                   <upbytes-angular-material-calendar-event-full-view class=\"calendar-full-view\"\n                                                              [event]=\"event\">\n                    </upbytes-angular-material-calendar-event-full-view>\n      </ng-template>\n      <ng-template ngFor let-event\n      [ngForOf]=\"multipleDayEvents\" \n      let-i=\"index\">\n      <upbytes-angular-material-calendar-event-full-view class=\"calendar-full-view\"\n                                                 [event]=\"event\">\n       </upbytes-angular-material-calendar-event-full-view>\n</ng-template>\n<upbytes-angular-material-calendar-hour-indicator></upbytes-angular-material-calendar-hour-indicator>\n</mat-grid-list>\n\n", styles: [""], components: [{ type: i3$1.MatGridList, selector: "mat-grid-list", inputs: ["cols", "gutterSize", "rowHeight"], exportAs: ["matGridList"] }, { type: i3$1.MatGridTile, selector: "mat-grid-tile", inputs: ["rowspan", "colspan"], exportAs: ["matGridTile"] }, { type: CalendarEventFullViewComponent, selector: "upbytes-angular-material-calendar-event-full-view", inputs: ["event"] }, { type: CalendarHourIndicatorComponent, selector: "upbytes-angular-material-calendar-hour-indicator" }], directives: [{ type: i5.NgForOf, selector: "[ngFor][ngForOf]", inputs: ["ngForOf", "ngForTrackBy", "ngForTemplate"] }, { type: i5.NgClass, selector: "[ngClass]", inputs: ["class", "ngClass"] }, { type: i5.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.1.1", ngImport: i0, type: CalendarWeekViewGridComponent, decorators: [{
            type: Component,
            args: [{ selector: 'upbytes-angular-material-calendar-week-view-grid', template: "<mat-grid-list cols=\"8\" \n               rowHeight=\"5em\" \n               gutterSize=\"0\">\n\n    <ng-template ngFor let-days \n                [ngForOf]=\"calendarHours\" \n                let-i=\"index\">\n\n                <mat-grid-tile class=\"calendar-week-view-grid\" \n                               id=\"week-{{trackByHour(i, tile)}}\"\n                               \n                               [ngClass]=\"[\n                               tile.isToday ? 'calendar-week-view-grid-today' : '',\n                               tile.isHourNow ? 'calendar-week-view-grid-hours' : '']\"\n                               *ngFor=\"let tile of days; let i=index; trackBy: trackByHour\">\n                               <div *ngIf=\"tile.isFirst && tile.hours! !== '0'\"\n                                     [ngClass]=\"tile.isFirst ? 'calendar-day-view-grid-first' : ''\" >\n                                   {{tile.hours}}\n                                   {{tile.day}}\n                               </div>\n                               <div *ngIf=\"tile.isFirst && tile.hours! === '0'\" \n                                    [ngClass]=\"tile.isFirst ? 'calendar-day-view-grid-first' : ''\" >\n                                     all-day\n                               </div>\n                               <div *ngIf=!tile.isFirst \n                               [ngClass]=\"!tile.isFirst ? 'calendar-week-view-grid-hour' : ''\" >\n                                   \n                               </div>\n\n                </mat-grid-tile>\n      </ng-template>\n      <ng-template ngFor let-event\n                   [ngForOf]=\"calendarEventsFull\" \n                   let-i=\"index\">\n                   <upbytes-angular-material-calendar-event-full-view class=\"calendar-full-view\"\n                                                              [event]=\"event\">\n                    </upbytes-angular-material-calendar-event-full-view>\n      </ng-template>\n      <ng-template ngFor let-event\n      [ngForOf]=\"multipleDayEvents\" \n      let-i=\"index\">\n      <upbytes-angular-material-calendar-event-full-view class=\"calendar-full-view\"\n                                                 [event]=\"event\">\n       </upbytes-angular-material-calendar-event-full-view>\n</ng-template>\n<upbytes-angular-material-calendar-hour-indicator></upbytes-angular-material-calendar-hour-indicator>\n</mat-grid-list>\n\n", styles: [""] }]
        }], ctorParameters: function () { return [{ type: i1$2.Store }, { type: CalendarHoursService }, { type: CalendarEventService }]; }, propDecorators: { events$: [{
                type: Input
            }] } });

class CalendarWeekViewComponent {
    constructor() { }
}
CalendarWeekViewComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.1.1", ngImport: i0, type: CalendarWeekViewComponent, deps: [], target: i0.ɵɵFactoryTarget.Component });
CalendarWeekViewComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "13.1.1", type: CalendarWeekViewComponent, selector: "upbytes-angular-material-calendar-week-view", inputs: { events$: "events$" }, ngImport: i0, template: "<upbytes-angular-material-calendar-week-view-header></upbytes-angular-material-calendar-week-view-header>\n\n\n    <div class=\"calendar-week-view\">\n        <upbytes-angular-material-calendar-week-view-grid [events$]=\"events$\">\n\n        </upbytes-angular-material-calendar-week-view-grid>\n    </div>\n", styles: [""], components: [{ type: CalendarWeekViewHeaderComponent, selector: "upbytes-angular-material-calendar-week-view-header" }, { type: CalendarWeekViewGridComponent, selector: "upbytes-angular-material-calendar-week-view-grid", inputs: ["events$"] }] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.1.1", ngImport: i0, type: CalendarWeekViewComponent, decorators: [{
            type: Component,
            args: [{ selector: 'upbytes-angular-material-calendar-week-view', template: "<upbytes-angular-material-calendar-week-view-header></upbytes-angular-material-calendar-week-view-header>\n\n\n    <div class=\"calendar-week-view\">\n        <upbytes-angular-material-calendar-week-view-grid [events$]=\"events$\">\n\n        </upbytes-angular-material-calendar-week-view-grid>\n    </div>\n", styles: [""] }]
        }], ctorParameters: function () { return []; }, propDecorators: { events$: [{
                type: Input
            }] } });

/**
 * @author vaibhav
 * calendar day view header comoponent should be displayed date/weekdaylong and GTM +timezone
 */
class CalendarDayViewHeaderComponent {
    constructor(store, _dateService) {
        this.store = store;
        this._dateService = _dateService;
        this.currentdate$ = store.select(selectCalendarDateState);
        this.currentdate$.subscribe((d) => {
            const redate = this._dateService.restoreFromStore(d);
            this.day = redate.current.weekdayLong;
            this.date = redate.current.day;
            this.timeZone = this._dateService.getTimeZoneFormat(d);
        });
    }
}
CalendarDayViewHeaderComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.1.1", ngImport: i0, type: CalendarDayViewHeaderComponent, deps: [{ token: i1$2.Store }, { token: DateService }], target: i0.ɵɵFactoryTarget.Component });
CalendarDayViewHeaderComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "13.1.1", type: CalendarDayViewHeaderComponent, selector: "upbytes-angular-material-calendar-day-view-header", ngImport: i0, template: "<div class=\"calendar-day-view-header-border\">\n<mat-grid-list cols=\"8\" \n               rowHeight=\"5em\" \n               gutterSize=\"0\">\n                <mat-grid-tile class=\"calendar-day-view-header\">\n                    <div class ='calendar-day-view-header-first'>\n                        {{timeZone}}\n                    </div>\n                </mat-grid-tile>\n                <mat-grid-tile class=\"calendar-day-view-header\"\n                              [colspan]=\"7\">\n                    <div class=\"calendar-day-view-grid-date\">\n                        <div class=\"calendar-day-view-header-date\">{{date}}</div>\n                        <div class=\"calendar-day-view-header-day\">{{day}}</div>\n                        \n                    </div>\n                </mat-grid-tile>\n</mat-grid-list>\n</div>", styles: [""], components: [{ type: i3$1.MatGridList, selector: "mat-grid-list", inputs: ["cols", "gutterSize", "rowHeight"], exportAs: ["matGridList"] }, { type: i3$1.MatGridTile, selector: "mat-grid-tile", inputs: ["rowspan", "colspan"], exportAs: ["matGridTile"] }] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.1.1", ngImport: i0, type: CalendarDayViewHeaderComponent, decorators: [{
            type: Component,
            args: [{ selector: 'upbytes-angular-material-calendar-day-view-header', template: "<div class=\"calendar-day-view-header-border\">\n<mat-grid-list cols=\"8\" \n               rowHeight=\"5em\" \n               gutterSize=\"0\">\n                <mat-grid-tile class=\"calendar-day-view-header\">\n                    <div class ='calendar-day-view-header-first'>\n                        {{timeZone}}\n                    </div>\n                </mat-grid-tile>\n                <mat-grid-tile class=\"calendar-day-view-header\"\n                              [colspan]=\"7\">\n                    <div class=\"calendar-day-view-grid-date\">\n                        <div class=\"calendar-day-view-header-date\">{{date}}</div>\n                        <div class=\"calendar-day-view-header-day\">{{day}}</div>\n                        \n                    </div>\n                </mat-grid-tile>\n</mat-grid-list>\n</div>", styles: [""] }]
        }], ctorParameters: function () { return [{ type: i1$2.Store }, { type: DateService }]; } });

/**
 * @author vaibhav
 * calendar day view gird component will display grid view of selected date and time.
 *
 */
class CalendarDayViewGridComponent {
    constructor(store, _calendarWeekService, _calendarEventService, _dateService) {
        this.store = store;
        this._calendarWeekService = _calendarWeekService;
        this._calendarEventService = _calendarEventService;
        this._dateService = _dateService;
        this.date$ = store.select(selectCalendarDateState);
    }
    ngOnInit() {
        this.date$.pipe(combineLatestWith(this.events$)).subscribe(([d, events]) => {
            this._currentDate = d;
            this.calendarHours = this._calendarWeekService
                .getCalndarDayHoursGridData(this._dateService.restoreFromStore(d));
            const filteredEventsArr = this._calendarWeekService.filterMultipleDayEvents(events);
            this.multipleDayEvents = this._calendarWeekService
                .findLeftForMultiDaysEventDay(filteredEventsArr[0], this._dateService.restoreFromStore(d));
            this.calendarEventsFull = this._calendarWeekService
                .filterEventsByDateAndStartTime(filteredEventsArr[1], this.calendarHours);
            this.calendarEventsFull = this._calendarEventService
                .filteredConflictedEvents(this.calendarEventsFull, 7);
        });
    }
    /**
     * component lifecycle hook will scroll view to current hour.
     */
    ngAfterViewInit() {
        document.getElementById(`day-hour-indicator`)?.scrollIntoView({
            behavior: 'smooth',
            block: 'center',
            inline: 'center'
        });
    }
    getColspan(d) {
        return d.isFirst ? 1 : 7;
    }
    trackByHour(index, el) {
        return el.hours;
    }
}
CalendarDayViewGridComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.1.1", ngImport: i0, type: CalendarDayViewGridComponent, deps: [{ token: i1$2.Store }, { token: CalendarHoursService }, { token: CalendarEventService }, { token: DateService }], target: i0.ɵɵFactoryTarget.Component });
CalendarDayViewGridComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "13.1.1", type: CalendarDayViewGridComponent, selector: "upbytes-angular-material-calendar-day-view-grid", inputs: { events$: "events$" }, ngImport: i0, template: "<mat-grid-list cols=\"8\" \n               rowHeight=\"5em\" \n               gutterSize=\"0\">\n\n    <ng-template ngFor let-days \n                [ngForOf]=\"calendarHours\" \n                let-i=\"index\">\n\n                <mat-grid-tile class=\"calendar-day-view-grid\" \n                               id=\"day-{{trackByHour(i, tile)}}\"\n                               [colspan]=\"getColspan(tile)\"\n                               [ngClass]=\"tile.isHourNow ? 'calendar-day-view-grid-hours' : 'calendar-day-view-grid'\"                               \n                               *ngFor=\"let tile of days; let i=index; trackBy: trackByHour\">\n                               <div *ngIf=\"tile.isFirst && tile.hours! !== '0'\"\n                                     [ngClass]=\"tile.isFirst ? 'calendar-day-view-grid-first' : ''\" >\n                                   {{tile.hours}}\n                                   {{tile.day}}\n                               </div>\n                               <div *ngIf=\"tile.isFirst && tile.hours! === '0'\" \n                                    [ngClass]=\"tile.isFirst ? 'calendar-day-view-grid-first' : ''\" >\n                                     all-day\n                               </div>\n                               <div *ngIf=!tile.isFirst \n                                    [ngClass]=\"!tile.isFirst ? 'calendar-day-view-grid-hour' : ''\" >\n                                   \n                               </div>\n                </mat-grid-tile>\n      </ng-template>\n      <ng-template ngFor let-event\n                   [ngForOf]=\"calendarEventsFull\" \n                   let-i=\"index\">\n                   <upbytes-angular-material-calendar-event-full-view class=\"calendar-full-view\"\n                                                              [event]=\"event\">\n                   </upbytes-angular-material-calendar-event-full-view>\n      </ng-template>\n      <ng-template ngFor let-event\n                  [ngForOf]=\"multipleDayEvents\" \n                  let-i=\"index\">\n                  <upbytes-angular-material-calendar-event-full-view class=\"calendar-full-view\"\n                                                 [event]=\"event\">\n                  </upbytes-angular-material-calendar-event-full-view>\n</ng-template>\n<upbytes-angular-material-calendar-hour-indicator></upbytes-angular-material-calendar-hour-indicator>\n</mat-grid-list>", styles: [""], components: [{ type: i3$1.MatGridList, selector: "mat-grid-list", inputs: ["cols", "gutterSize", "rowHeight"], exportAs: ["matGridList"] }, { type: i3$1.MatGridTile, selector: "mat-grid-tile", inputs: ["rowspan", "colspan"], exportAs: ["matGridTile"] }, { type: CalendarEventFullViewComponent, selector: "upbytes-angular-material-calendar-event-full-view", inputs: ["event"] }, { type: CalendarHourIndicatorComponent, selector: "upbytes-angular-material-calendar-hour-indicator" }], directives: [{ type: i5.NgForOf, selector: "[ngFor][ngForOf]", inputs: ["ngForOf", "ngForTrackBy", "ngForTemplate"] }, { type: i5.NgClass, selector: "[ngClass]", inputs: ["class", "ngClass"] }, { type: i5.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.1.1", ngImport: i0, type: CalendarDayViewGridComponent, decorators: [{
            type: Component,
            args: [{ selector: 'upbytes-angular-material-calendar-day-view-grid', template: "<mat-grid-list cols=\"8\" \n               rowHeight=\"5em\" \n               gutterSize=\"0\">\n\n    <ng-template ngFor let-days \n                [ngForOf]=\"calendarHours\" \n                let-i=\"index\">\n\n                <mat-grid-tile class=\"calendar-day-view-grid\" \n                               id=\"day-{{trackByHour(i, tile)}}\"\n                               [colspan]=\"getColspan(tile)\"\n                               [ngClass]=\"tile.isHourNow ? 'calendar-day-view-grid-hours' : 'calendar-day-view-grid'\"                               \n                               *ngFor=\"let tile of days; let i=index; trackBy: trackByHour\">\n                               <div *ngIf=\"tile.isFirst && tile.hours! !== '0'\"\n                                     [ngClass]=\"tile.isFirst ? 'calendar-day-view-grid-first' : ''\" >\n                                   {{tile.hours}}\n                                   {{tile.day}}\n                               </div>\n                               <div *ngIf=\"tile.isFirst && tile.hours! === '0'\" \n                                    [ngClass]=\"tile.isFirst ? 'calendar-day-view-grid-first' : ''\" >\n                                     all-day\n                               </div>\n                               <div *ngIf=!tile.isFirst \n                                    [ngClass]=\"!tile.isFirst ? 'calendar-day-view-grid-hour' : ''\" >\n                                   \n                               </div>\n                </mat-grid-tile>\n      </ng-template>\n      <ng-template ngFor let-event\n                   [ngForOf]=\"calendarEventsFull\" \n                   let-i=\"index\">\n                   <upbytes-angular-material-calendar-event-full-view class=\"calendar-full-view\"\n                                                              [event]=\"event\">\n                   </upbytes-angular-material-calendar-event-full-view>\n      </ng-template>\n      <ng-template ngFor let-event\n                  [ngForOf]=\"multipleDayEvents\" \n                  let-i=\"index\">\n                  <upbytes-angular-material-calendar-event-full-view class=\"calendar-full-view\"\n                                                 [event]=\"event\">\n                  </upbytes-angular-material-calendar-event-full-view>\n</ng-template>\n<upbytes-angular-material-calendar-hour-indicator></upbytes-angular-material-calendar-hour-indicator>\n</mat-grid-list>", styles: [""] }]
        }], ctorParameters: function () { return [{ type: i1$2.Store }, { type: CalendarHoursService }, { type: CalendarEventService }, { type: DateService }]; }, propDecorators: { events$: [{
                type: Input
            }] } });

class CalendarDayViewComponent {
    constructor() { }
}
CalendarDayViewComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.1.1", ngImport: i0, type: CalendarDayViewComponent, deps: [], target: i0.ɵɵFactoryTarget.Component });
CalendarDayViewComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "13.1.1", type: CalendarDayViewComponent, selector: "upbytes-angular-material-calendar-day-view", inputs: { events$: "events$" }, ngImport: i0, template: "<upbytes-angular-material-calendar-day-view-header>\n\n</upbytes-angular-material-calendar-day-view-header>\n\n\n    <div class=\"calendar-day-view\">\n        <upbytes-angular-material-calendar-day-view-grid [events$]=\"events$\"> \n\n        </upbytes-angular-material-calendar-day-view-grid>\n    </div>\n", styles: [""], components: [{ type: CalendarDayViewHeaderComponent, selector: "upbytes-angular-material-calendar-day-view-header" }, { type: CalendarDayViewGridComponent, selector: "upbytes-angular-material-calendar-day-view-grid", inputs: ["events$"] }] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.1.1", ngImport: i0, type: CalendarDayViewComponent, decorators: [{
            type: Component,
            args: [{ selector: 'upbytes-angular-material-calendar-day-view', template: "<upbytes-angular-material-calendar-day-view-header>\n\n</upbytes-angular-material-calendar-day-view-header>\n\n\n    <div class=\"calendar-day-view\">\n        <upbytes-angular-material-calendar-day-view-grid [events$]=\"events$\"> \n\n        </upbytes-angular-material-calendar-day-view-grid>\n    </div>\n", styles: [""] }]
        }], ctorParameters: function () { return []; }, propDecorators: { events$: [{
                type: Input
            }] } });

/**
 * @author vaibhav
 * Angular material component is entry coponent for this library.
 * It takes input as array, datasource and observable.
 */
class AngularMaterialCalendarComponent {
    constructor(store, calendarViewPortService, calendarConfigService, calendarEventInputAdapter) {
        this.store = store;
        this.calendarViewPortService = calendarViewPortService;
        this.calendarConfigService = calendarConfigService;
        this.calendarEventInputAdapter = calendarEventInputAdapter;
        this._destroyed$ = new Subject();
        this._events$ = new BehaviorSubject([]);
        this.viewChange = new BehaviorSubject({
            start: 0,
            end: Number.MAX_VALUE,
        });
        this.initialView(this.calendarConfigService.view);
        this._view$ = store.select(selectCalendarViewState);
        this._view$.subscribe((v) => this._view = v);
    }
    ngAfterContentChecked() {
        if (this.dataSource && !this._renderEventSubscription$) {
            this._observeRenderChanges();
        }
    }
    ngOnInit() {
        this.calendarViewPortService.viewportResize();
    }
    get dataSource() {
        return this._dataSource;
    }
    set dataSource(dataSource) {
        this._switchDataSource(dataSource);
    }
    _switchDataSource(dataSource) {
        this._data = [];
        if (isDataSource(this.dataSource)) {
            this.dataSource.disconnect(this);
        }
        if (this._renderEventSubscription$) {
            this._renderEventSubscription$.unsubscribe();
            this._renderEventSubscription$ = undefined;
        }
        this._dataSource = dataSource;
    }
    _observeRenderChanges() {
        if (!this.dataSource) {
            return;
        }
        let dataStream$;
        if (isDataSource(this.dataSource)) {
            dataStream$ = this.dataSource.connect(this);
        }
        else if (isObservable(this.dataSource)) {
            dataStream$ = this.dataSource;
        }
        else if (Array.isArray(this.dataSource)) {
            dataStream$ = of(this.dataSource);
        }
        this._renderEventSubscription$ = dataStream$
            .pipe(takeUntil(this._destroyed$))
            .subscribe(data => {
            const transform = data.map((d) => this.calendarEventInputAdapter.adapt(d)) || [];
            this._events$?.next(this.calendarEventInputAdapter.sort(transform));
        });
    }
    ngOnDestroy() {
        this._destroyed$.next();
        this._destroyed$.complete();
        this._events$?.next([]);
        this._events$?.complete();
        if (isDataSource(this.dataSource)) {
            this.dataSource.disconnect(this);
        }
    }
    initialView(view) {
        switch (view) {
            case 'month':
                this.store.dispatch(month());
                break;
            case 'week':
                this.store.dispatch(week());
                break;
            case 'day':
                this.store.dispatch(day());
                break;
            default:
                this.store.dispatch(month());
                break;
        }
    }
}
AngularMaterialCalendarComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.1.1", ngImport: i0, type: AngularMaterialCalendarComponent, deps: [{ token: i1$2.Store }, { token: CalendarViewPortService }, { token: CalendarServiceConfig }, { token: CalendarEventInputAdapter }], target: i0.ɵɵFactoryTarget.Component });
AngularMaterialCalendarComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "13.1.1", type: AngularMaterialCalendarComponent, selector: "upbytes-angular-material-calendar", inputs: { dataSource: "dataSource" }, ngImport: i0, template: "<upbytes-angular-material-calendar-header class=\"calendar-header\">\n\n</upbytes-angular-material-calendar-header>\n<upbytes-angular-material-calendar-month-view *ngIf=\"_view!.view === 'month'\"\n                                      [events$]=\"_events$\">\n    \n</upbytes-angular-material-calendar-month-view>\n\n<upbytes-angular-material-calendar-week-view  *ngIf=\"_view!.view === 'week'\"\n                                      [events$]=\"_events$\">\n    \n</upbytes-angular-material-calendar-week-view>\n\n<upbytes-angular-material-calendar-day-view  *ngIf=\"_view!.view === 'day'\"\n                                     [events$]=\"_events$\">\n    \n</upbytes-angular-material-calendar-day-view> ", styles: [".calendar-header{display:flex;margin-bottom:.5em}\n"], components: [{ type: CalendarHeaderComponent, selector: "upbytes-angular-material-calendar-header" }, { type: CalendarMonthViewComponent, selector: "upbytes-angular-material-calendar-month-view", inputs: ["events$"] }, { type: CalendarWeekViewComponent, selector: "upbytes-angular-material-calendar-week-view", inputs: ["events$"] }, { type: CalendarDayViewComponent, selector: "upbytes-angular-material-calendar-day-view", inputs: ["events$"] }], directives: [{ type: i5.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.1.1", ngImport: i0, type: AngularMaterialCalendarComponent, decorators: [{
            type: Component,
            args: [{ selector: 'upbytes-angular-material-calendar', template: "<upbytes-angular-material-calendar-header class=\"calendar-header\">\n\n</upbytes-angular-material-calendar-header>\n<upbytes-angular-material-calendar-month-view *ngIf=\"_view!.view === 'month'\"\n                                      [events$]=\"_events$\">\n    \n</upbytes-angular-material-calendar-month-view>\n\n<upbytes-angular-material-calendar-week-view  *ngIf=\"_view!.view === 'week'\"\n                                      [events$]=\"_events$\">\n    \n</upbytes-angular-material-calendar-week-view>\n\n<upbytes-angular-material-calendar-day-view  *ngIf=\"_view!.view === 'day'\"\n                                     [events$]=\"_events$\">\n    \n</upbytes-angular-material-calendar-day-view> ", styles: [".calendar-header{display:flex;margin-bottom:.5em}\n"] }]
        }], ctorParameters: function () { return [{ type: i1$2.Store }, { type: CalendarViewPortService }, { type: CalendarServiceConfig }, { type: CalendarEventInputAdapter }]; }, propDecorators: { dataSource: [{
                type: Input
            }] } });

class CalendarViewReducerService {
    constructor() { }
    getReducer() {
        return createReducer({ view: 'month' }, on(month, () => ({
            view: 'month'
        })), on(week, () => ({
            view: 'week'
        })), on(day, () => ({
            view: 'day'
        })));
    }
}
CalendarViewReducerService.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.1.1", ngImport: i0, type: CalendarViewReducerService, deps: [], target: i0.ɵɵFactoryTarget.Injectable });
CalendarViewReducerService.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "13.1.1", ngImport: i0, type: CalendarViewReducerService, providedIn: 'root' });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.1.1", ngImport: i0, type: CalendarViewReducerService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root'
                }]
        }], ctorParameters: function () { return []; } });

class DateReducerService {
    constructor(_dateService) {
        this._dateService = _dateService;
    }
    getReducer() {
        return createReducer(this._dateService.today(), on(increment, (state, _view) => {
            if (_view.view === 'month') {
                return this._dateService.addCalendarMonths(state, 1);
            }
            else if (_view.view === 'week') {
                return this._dateService.addCalendarWeeks(state, 1);
            }
            else if (_view.view === 'day') {
                return this._dateService.addCalendarDays(state, 1);
            }
            else {
                return this._dateService.addCalendarDays(state, 1);
            }
        }), on(decrement, (state, _view) => {
            if (_view.view === 'month') {
                return this._dateService.subtractCalendarMonths(state, 1);
            }
            else if (_view.view === 'week') {
                return this._dateService.subtractCalendarWeeks(state, 1);
            }
            else if (_view.view === 'day') {
                return this._dateService.subtractCalendarDays(state, 1);
            }
            else {
                return this._dateService.subtractCalendarDays(state, 1);
            }
        }), on(reset, () => this._dateService.today()), on(goto, (state, _gotoDate) => this._dateService.setDate(_gotoDate.current.day, _gotoDate.current.month, _gotoDate.current.year, state)));
    }
}
DateReducerService.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.1.1", ngImport: i0, type: DateReducerService, deps: [{ token: DateService }], target: i0.ɵɵFactoryTarget.Injectable });
DateReducerService.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "13.1.1", ngImport: i0, type: DateReducerService, providedIn: 'root' });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.1.1", ngImport: i0, type: DateReducerService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root'
                }]
        }], ctorParameters: function () { return [{ type: DateService }]; } });

class MaterialModule {
}
MaterialModule.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.1.1", ngImport: i0, type: MaterialModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
MaterialModule.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "12.0.0", version: "13.1.1", ngImport: i0, type: MaterialModule, exports: [A11yModule,
        BrowserAnimationsModule,
        DragDropModule,
        MatButtonModule,
        MatCardModule,
        MatDialogModule,
        MatGridListModule,
        MatIconModule,
        MatListModule,
        LayoutModule] });
MaterialModule.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "13.1.1", ngImport: i0, type: MaterialModule, imports: [A11yModule,
        BrowserAnimationsModule,
        DragDropModule,
        MatButtonModule,
        MatCardModule,
        MatDialogModule,
        MatGridListModule,
        MatIconModule,
        MatListModule,
        LayoutModule] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.1.1", ngImport: i0, type: MaterialModule, decorators: [{
            type: NgModule,
            args: [{
                    exports: [
                        A11yModule,
                        BrowserAnimationsModule,
                        DragDropModule,
                        MatButtonModule,
                        MatCardModule,
                        MatDialogModule,
                        MatGridListModule,
                        MatIconModule,
                        MatListModule,
                        LayoutModule
                    ]
                }]
        }] });

class CalendarEventViewModule {
}
CalendarEventViewModule.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.1.1", ngImport: i0, type: CalendarEventViewModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
CalendarEventViewModule.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "12.0.0", version: "13.1.1", ngImport: i0, type: CalendarEventViewModule, declarations: [CalendarEventViewComponent,
        CalendarEventFullViewComponent,
        CalendarEventDialog], imports: [CommonModule,
        MaterialModule], exports: [CalendarEventViewComponent,
        CalendarEventFullViewComponent] });
CalendarEventViewModule.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "13.1.1", ngImport: i0, type: CalendarEventViewModule, providers: [
        CalendarHoursService
    ], imports: [[
            CommonModule,
            MaterialModule
        ]] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.1.1", ngImport: i0, type: CalendarEventViewModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: [
                        CalendarEventViewComponent,
                        CalendarEventFullViewComponent,
                        CalendarEventDialog
                    ],
                    imports: [
                        CommonModule,
                        MaterialModule
                    ],
                    exports: [
                        CalendarEventViewComponent,
                        CalendarEventFullViewComponent
                    ],
                    providers: [
                        CalendarHoursService
                    ]
                }]
        }] });

class CalendarMonthViewModule {
}
CalendarMonthViewModule.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.1.1", ngImport: i0, type: CalendarMonthViewModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
CalendarMonthViewModule.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "12.0.0", version: "13.1.1", ngImport: i0, type: CalendarMonthViewModule, declarations: [CalendarMonthViewComponent,
        CalendarMonthViewGridHeaderComponent,
        CalendarMonthViewGridComponent], imports: [CommonModule,
        MaterialModule,
        CalendarEventViewModule], exports: [CalendarMonthViewComponent] });
CalendarMonthViewModule.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "13.1.1", ngImport: i0, type: CalendarMonthViewModule, providers: [MonthViewService
    ], imports: [[
            CommonModule,
            MaterialModule,
            CalendarEventViewModule
        ]] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.1.1", ngImport: i0, type: CalendarMonthViewModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: [
                        CalendarMonthViewComponent,
                        CalendarMonthViewGridHeaderComponent,
                        CalendarMonthViewGridComponent
                    ],
                    imports: [
                        CommonModule,
                        MaterialModule,
                        CalendarEventViewModule
                    ],
                    exports: [
                        CalendarMonthViewComponent
                    ],
                    providers: [MonthViewService
                    ]
                }]
        }] });

class CalendarHeaderModule {
}
CalendarHeaderModule.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.1.1", ngImport: i0, type: CalendarHeaderModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
CalendarHeaderModule.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "12.0.0", version: "13.1.1", ngImport: i0, type: CalendarHeaderModule, declarations: [CalendarHeaderComponent,
        CalendarNavigatorComponent,
        CalendarHeaderLabelComponent,
        CalendarHeaderToggelComponent], imports: [CommonModule,
        MaterialModule], exports: [CalendarHeaderComponent] });
CalendarHeaderModule.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "13.1.1", ngImport: i0, type: CalendarHeaderModule, providers: [
        DateService
    ], imports: [[
            CommonModule,
            MaterialModule
        ]] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.1.1", ngImport: i0, type: CalendarHeaderModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: [
                        CalendarHeaderComponent,
                        CalendarNavigatorComponent,
                        CalendarHeaderLabelComponent,
                        CalendarHeaderToggelComponent
                    ],
                    imports: [
                        CommonModule,
                        MaterialModule
                    ],
                    exports: [
                        CalendarHeaderComponent
                    ],
                    providers: [
                        DateService
                    ]
                }]
        }] });

class CalendarHourIndicatorModule {
}
CalendarHourIndicatorModule.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.1.1", ngImport: i0, type: CalendarHourIndicatorModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
CalendarHourIndicatorModule.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "12.0.0", version: "13.1.1", ngImport: i0, type: CalendarHourIndicatorModule, declarations: [CalendarHourIndicatorComponent], imports: [CommonModule,
        MaterialModule], exports: [CalendarHourIndicatorComponent] });
CalendarHourIndicatorModule.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "13.1.1", ngImport: i0, type: CalendarHourIndicatorModule, providers: [
        CalendarHourIndicatorService
    ], imports: [[
            CommonModule,
            MaterialModule
        ]] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.1.1", ngImport: i0, type: CalendarHourIndicatorModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: [
                        CalendarHourIndicatorComponent
                    ],
                    imports: [
                        CommonModule,
                        MaterialModule
                    ],
                    exports: [
                        CalendarHourIndicatorComponent
                    ],
                    providers: [
                        CalendarHourIndicatorService
                    ]
                }]
        }] });

class CalendarWeekViewModule {
}
CalendarWeekViewModule.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.1.1", ngImport: i0, type: CalendarWeekViewModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
CalendarWeekViewModule.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "12.0.0", version: "13.1.1", ngImport: i0, type: CalendarWeekViewModule, declarations: [CalendarWeekViewComponent,
        CalendarWeekViewGridComponent,
        CalendarWeekViewHeaderComponent], imports: [CommonModule,
        MaterialModule,
        CalendarEventViewModule,
        CalendarHourIndicatorModule], exports: [CalendarWeekViewComponent] });
CalendarWeekViewModule.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "13.1.1", ngImport: i0, type: CalendarWeekViewModule, providers: [
        CalendarHoursService
    ], imports: [[
            CommonModule,
            MaterialModule,
            CalendarEventViewModule,
            CalendarHourIndicatorModule
        ]] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.1.1", ngImport: i0, type: CalendarWeekViewModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: [
                        CalendarWeekViewComponent,
                        CalendarWeekViewGridComponent,
                        CalendarWeekViewHeaderComponent
                    ],
                    imports: [
                        CommonModule,
                        MaterialModule,
                        CalendarEventViewModule,
                        CalendarHourIndicatorModule
                    ],
                    exports: [
                        CalendarWeekViewComponent
                    ],
                    providers: [
                        CalendarHoursService
                    ]
                }]
        }] });

class CalendarDayViewModule {
}
CalendarDayViewModule.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.1.1", ngImport: i0, type: CalendarDayViewModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
CalendarDayViewModule.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "12.0.0", version: "13.1.1", ngImport: i0, type: CalendarDayViewModule, declarations: [CalendarDayViewComponent,
        CalendarDayViewHeaderComponent,
        CalendarDayViewGridComponent], imports: [CommonModule,
        MaterialModule,
        CalendarEventViewModule,
        CalendarHourIndicatorModule], exports: [CalendarDayViewComponent] });
CalendarDayViewModule.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "13.1.1", ngImport: i0, type: CalendarDayViewModule, providers: [
        CalendarHoursService
    ], imports: [[
            CommonModule,
            MaterialModule,
            CalendarEventViewModule,
            CalendarHourIndicatorModule
        ]] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.1.1", ngImport: i0, type: CalendarDayViewModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: [
                        CalendarDayViewComponent,
                        CalendarDayViewHeaderComponent,
                        CalendarDayViewGridComponent
                    ],
                    imports: [
                        CommonModule,
                        MaterialModule,
                        CalendarEventViewModule,
                        CalendarHourIndicatorModule
                    ],
                    exports: [
                        CalendarDayViewComponent
                    ],
                    providers: [
                        CalendarHoursService
                    ]
                }]
        }] });

const CALENDAR_REDUCER_TOKEN = new InjectionToken('Registered Upbyets Calendar Reducers', {
    factory: () => {
        const viewReducer = inject(CalendarViewReducerService).getReducer();
        const dateReducer = inject(DateReducerService).getReducer();
        const reducers = {
            _date: dateReducer,
            _view: viewReducer
        };
        return reducers;
    }
});
class AngularMaterialCalendarModule {
    constructor(parentModule) {
        if (parentModule) {
            throw new Error('AngularMaterialCalendarModule is already loaded. Import it in the other module only');
        }
    }
    static forRoot(config) {
        return {
            ngModule: AngularMaterialCalendarModule,
            providers: [
                { provide: CalendarConfig, useValue: config }
            ]
        };
    }
}
AngularMaterialCalendarModule.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.1.1", ngImport: i0, type: AngularMaterialCalendarModule, deps: [{ token: AngularMaterialCalendarModule, optional: true, skipSelf: true }], target: i0.ɵɵFactoryTarget.NgModule });
AngularMaterialCalendarModule.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "12.0.0", version: "13.1.1", ngImport: i0, type: AngularMaterialCalendarModule, declarations: [AngularMaterialCalendarComponent], imports: [LuxonDateModule, i1$2.StoreFeatureModule, CommonModule,
        MaterialModule,
        CalendarMonthViewModule,
        CalendarWeekViewModule,
        CalendarHeaderModule,
        CalendarDayViewModule,
        CalendarEventViewModule,
        CalendarHourIndicatorModule], exports: [AngularMaterialCalendarComponent] });
AngularMaterialCalendarModule.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "13.1.1", ngImport: i0, type: AngularMaterialCalendarModule, providers: [
        DateService,
        DateReducerService,
        CalendarViewReducerService,
        CalendarViewPortService,
        {
            provide: DateAdapter,
            useClass: LuxonDateAdapter,
            deps: [MAT_DATE_LOCALE, MAT_LUXON_DATE_ADAPTER_OPTIONS]
        }
    ], imports: [[
            LuxonDateModule,
            //StoreModule.forRoot(CALENDAR_REDUCER_TOKEN),
            StoreModule.forFeature("upbytes_calendar", CALENDAR_REDUCER_TOKEN),
            CommonModule,
            MaterialModule,
            CalendarMonthViewModule,
            CalendarWeekViewModule,
            CalendarHeaderModule,
            CalendarDayViewModule,
            CalendarEventViewModule,
            CalendarHourIndicatorModule
        ]] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.1.1", ngImport: i0, type: AngularMaterialCalendarModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: [
                        AngularMaterialCalendarComponent
                    ],
                    imports: [
                        LuxonDateModule,
                        //StoreModule.forRoot(CALENDAR_REDUCER_TOKEN),
                        StoreModule.forFeature("upbytes_calendar", CALENDAR_REDUCER_TOKEN),
                        CommonModule,
                        MaterialModule,
                        CalendarMonthViewModule,
                        CalendarWeekViewModule,
                        CalendarHeaderModule,
                        CalendarDayViewModule,
                        CalendarEventViewModule,
                        CalendarHourIndicatorModule
                    ],
                    exports: [
                        AngularMaterialCalendarComponent
                    ],
                    providers: [
                        DateService,
                        DateReducerService,
                        CalendarViewReducerService,
                        CalendarViewPortService,
                        {
                            provide: DateAdapter,
                            useClass: LuxonDateAdapter,
                            deps: [MAT_DATE_LOCALE, MAT_LUXON_DATE_ADAPTER_OPTIONS]
                        }
                    ]
                }]
        }], ctorParameters: function () { return [{ type: AngularMaterialCalendarModule, decorators: [{
                    type: Optional
                }, {
                    type: SkipSelf
                }] }]; } });

/*
 * Public API Surface of angular-material-calendar
 */

/**
 * Generated bundle index. Do not edit.
 */

export { AngularMaterialCalendarComponent, AngularMaterialCalendarModule, CALENDAR_REDUCER_TOKEN };
