import { DateTime } from 'luxon';
import { CalendarDate } from '../calendar-modal/calendar-date/calendar-date';
import { DateAdapter } from '@angular/material/core';
import { CalendarServiceConfig } from './calendar-config.service';
import * as i0 from "@angular/core";
/**
 * helps to return range of given length.
 * @param length
 * @param lamdaFunction
 * @returns T[]
 */
export declare function dateRange<T>(length: number, lamdaFunction: (index: number) => T): T[];
/**
 * @author vaibhav
 * Date service is perform various operation on dateTime. it is based on DateAdapter implementation
 * of angular material and DateTime object of Luxon library.
 * Manipulate date in number.
 *
 */
export declare class DateService {
    private _dateAdapter;
    private calendarServiceConfig;
    constructor(_dateAdapter: DateAdapter<DateTime>, calendarServiceConfig: CalendarServiceConfig);
    today(): CalendarDate;
    addCalendarYears(date: CalendarDate, years: number): CalendarDate;
    addCalendarMonths(date: CalendarDate, months: number): CalendarDate;
    addCalendarDays(date: CalendarDate, days: number): CalendarDate;
    addCalendarWeeks(date: CalendarDate, weeks: number): CalendarDate;
    subtractCalendarYears(date: CalendarDate, years: number): CalendarDate;
    subtractCalendarMonths(date: CalendarDate, months: number): CalendarDate;
    subtractCalendarDays(date: CalendarDate, days: number): CalendarDate;
    subtractCalendarWeeks(date: CalendarDate, weeks: number): CalendarDate;
    getMonthNames(date: CalendarDate, style: 'long' | 'short' | 'narrow'): string;
    getYearName(date: CalendarDate): string;
    getDayName(date: CalendarDate, style: 'long' | 'short' | 'narrow'): string;
    getYear(date: CalendarDate): number;
    getMonth(date: CalendarDate): number;
    getDate(date: CalendarDate): number;
    getFirstDayOfMonth(date: CalendarDate): CalendarDate;
    getLastDayOfMonth(date: CalendarDate): CalendarDate;
    getFirstDayOfWeek(date: CalendarDate): CalendarDate;
    getLastDayOfWeek(date: CalendarDate): CalendarDate;
    getDaysInMonthRange(date: CalendarDate): number;
    getDayOfWeekNames(style: 'long' | 'short' | 'narrow'): string[];
    getDayOfWeekNamesFromMonday(style: 'long' | 'short' | 'narrow'): string[];
    getMonthDatesRange(date: CalendarDate): CalendarDate[];
    getWeekDatesRange(date: CalendarDate): CalendarDate[];
    getHoursFormat(): string[];
    isToday(date: CalendarDate): boolean;
    isHoursNow(hours: string): boolean;
    getTimeZoneFormat(date: CalendarDate): string;
    getDateTime<T extends number | string>(d: T): DateTime;
    getDateTimeFromFormat(d: string): DateTime;
    getDateTimeFromString(d: string): DateTime;
    isSameHour(hours: string, eventDate: number): boolean;
    isSameDate<T extends CalendarDate | number>(date: T, eventDate: number): boolean;
    timeDiff(start: number, end: number): import("luxon").DurationObjectUnits;
    timeDiffinHours(start: number, end: number): number | undefined;
    timeDiffinMinutes(start: number, end: number): number | undefined;
    minute(start: number): number;
    getTimeFormat(d: number): string;
    restoreFromStore(d: CalendarDate): CalendarDate;
    isBetween(date: CalendarDate, start: number, end: number): boolean;
    setDate(date: number, month: number, year: number, _currentDate: CalendarDate): {
        current: DateTime;
    };
    static ɵfac: i0.ɵɵFactoryDeclaration<DateService, [null, { optional: true; }]>;
    static ɵprov: i0.ɵɵInjectableDeclaration<DateService>;
}
